@@ -20,7 +20,7 @@
 #ifndef RGB_F16HALF_PLUGIN_H_
 #define RGB_F16HALF_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the RGB F16Half colour space strategy.
@@ -28,7 +28,7 @@
 class RGBF16HalfPlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     RGBF16HalfPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~RGBF16HalfPlugin();
