@@ -19,7 +19,7 @@
 #ifndef WET_PLUGIN_H_
 #define WET_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 #include "kis_types.h"
 
@@ -32,7 +32,7 @@ class KisWetColorSpace;
 class WetPlugin : public KParts::Plugin
 {
      Q_OBJECT
-  TQ_OBJECT
+  
 public:
     WetPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~WetPlugin();
