@@ -19,7 +19,7 @@
 #ifndef YCBCR_U16_PLUGIN_H_
 #define YCBCR_U16_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the YCbCr U16 colour space strategy.
@@ -27,7 +27,7 @@
 class YCbCrU16Plugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     YCbCrU16Plugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~YCbCrU16Plugin();
