@@ -149,7 +149,7 @@ def createDCOP(header):
 		classname = classname + part.capitalize()
 		classname_upper = classname_upper + part.upper() + "_"
 	ifaceheader = header[:-2] + "_iface.h"
-	ifaceimplementation = header[:-2] + "_iface.cc"
+	ifaceimplementation = header[:-2] + "_iface.cpp"
 	ifaceclass = classname + "Iface"
 
 	#print "with: ", implementation, classname, classname_upper, ifaceheader, ifaceimplementation, ifaceclass
