@@ -36,7 +36,7 @@ class KisMathToolbox : public TQObject {
   
     public:
         struct KisFloatRepresentation {
-            KisFloatRepresentation(uint nsize, uint ndepth) throw(std::bad_alloc ) : coeffs(new float[nsize*nsize*ndepth]) ,size(nsize), depth(ndepth)
+            KisFloatRepresentation(uint nsize, uint ndepth) : coeffs(new float[nsize*nsize*ndepth]) ,size(nsize), depth(ndepth)
             {
                 // XXX: Valgrind shows that these are being used without being initialised.
                 for (TQ_UINT32 i = 0; i < nsize*nsize*ndepth; ++i) {
@@ -58,7 +58,7 @@ class KisMathToolbox : public TQObject {
          * This function initialize a wavelet structure
          * @param lay the layer that will be used for the transformation
          */
-        inline KisWavelet* initWavelet(KisPaintDeviceSP lay, const TQRect&) throw(std::bad_alloc );
+        inline KisWavelet* initWavelet(KisPaintDeviceSP lay, const TQRect&);
         inline uint fastWaveletTotalSteps(const TQRect&);
         /**
          * This function reconstruct the layer from the information of a wavelet
@@ -103,7 +103,7 @@ class KisMathToolboxFactoryRegistry : public KisGenericRegistry<KisMathToolbox*>
 };
 
 
-inline KisMathToolbox::KisWavelet* KisMathToolbox::initWavelet(KisPaintDeviceSP src, const TQRect& rect) throw(std::bad_alloc )
+inline KisMathToolbox::KisWavelet* KisMathToolbox::initWavelet(KisPaintDeviceSP src, const TQRect& rect)
 {
     int size;
     int maxrectsize = (rect.height() < rect.width()) ? rect.width() : rect.height();
