@@ -25,7 +25,7 @@
 #define LCMS_HEADER <lcms.h>
 // TODO: remove it !
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class UnsharpPlugin : public KParts::Plugin
 {
