@@ -19,7 +19,7 @@
 #ifndef DEFAULT_PAINTOPS_PLUGIN_H_
 #define DEFAULT_PAINTOPS_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper that adds the paintop factories to the paintop registry.
@@ -27,7 +27,7 @@
 class DefaultPaintOpsPlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     DefaultPaintOpsPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~DefaultPaintOpsPlugin();
