@@ -22,7 +22,7 @@
 #ifndef _KRITA_FILTERS_PREVIEW_H_
 #define _KRITA_FILTERS_PREVIEW_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
@@ -32,7 +32,7 @@ namespace FiltersGallery {
     class ChalkFiltersGallery : public KParts::Plugin
     {
         Q_OBJECT
-  TQ_OBJECT
+  
         public:
             ChalkFiltersGallery(TQObject *parent, const char *name, const TQStringList &);
             virtual ~ChalkFiltersGallery();
