@@ -20,14 +20,14 @@
 #ifndef SCREENSHOT_H
 #define SCREENSHOT_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KSnapshot;
 
 class Screenshot : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     Screenshot(TQObject *parent, const char *name, const TQStringList &);
     virtual ~Screenshot();
