@@ -20,14 +20,14 @@
 #ifndef SHEARIMAGE_H
 #define SHEARIMAGE_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
 class ShearImage : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     ShearImage(TQObject *parent, const char *name, const TQStringList &);
     virtual ~ShearImage();
