@@ -21,14 +21,14 @@
 #ifndef SUBSTATE_H
 #define SUBSTATE_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
 class SubstratePlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     SubstratePlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~SubstratePlugin();
