@@ -30,14 +30,14 @@
 #include <tqsimplerichtext.h>
 #include <tqtimer.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
 #include <kiconloader.h>
 #include <klineedit.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <kstringhandler.h>
 
 class LayerItemIterator: public TQListViewItemIterator
@@ -80,7 +80,7 @@ public:
     bool previewsShown;
     int itemHeight;
     TQValueList<LayerProperty> properties;
-    KPopupMenu contextMenu;
+    TDEPopupMenu contextMenu;
     LayerToolTip *tooltip;
 
     Private( TQWidget *parent, LayerList *list );
@@ -456,7 +456,7 @@ bool LayerList::property( int id, const TQString &name ) const
     return l->property( name );
 }
 
-KPopupMenu *LayerList::contextMenu() const
+TDEPopupMenu *LayerList::contextMenu() const
 {
     return &( d->contextMenu );
 }
@@ -733,14 +733,14 @@ void LayerList::constructMenu( LayerItem *layer )
         for( int i = 0, n = d->properties.count(); i < n; ++i )
             if( !layer->isFolder() || d->properties[i].validForFolders )
                 d->contextMenu.insertItem( layer->d->properties[i] ? d->properties[i].enabledIcon : d->properties[i].disabledIcon, d->properties[i].displayName, MenuItems::COUNT + i );
-        d->contextMenu.insertItem( SmallIconSet( "info" ), i18n( "&Properties" ), MenuItems::LayerProperties );
+        d->contextMenu.insertItem( SmallIconSet( "application-vnd.tde.info" ), i18n( "&Properties" ), MenuItems::LayerProperties );
         d->contextMenu.insertSeparator();
-        d->contextMenu.insertItem( SmallIconSet( "editdelete" ),
+        d->contextMenu.insertItem( SmallIconSet( "edit-delete" ),
             selectedLayers().count() > 1 ? i18n( "Remove Layers" )
                    : layer->isFolder() ? i18n( "&Remove Folder" )
                                        : i18n( "&Remove Layer" ), MenuItems::RemoveLayer );
     }
-    d->contextMenu.insertItem( SmallIconSet( "filenew" ), i18n( "&New Layer" ), MenuItems::NewLayer );
+    d->contextMenu.insertItem( SmallIconSet( "document-new" ), i18n( "&New Layer" ), MenuItems::NewLayer );
     d->contextMenu.insertItem( SmallIconSet( "folder" ), i18n( "New &Folder" ), MenuItems::NewFolder );
 }
 
