@@ -25,7 +25,7 @@
 #include <tqimage.h>
 
 #include <kdebug.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <kmimetype.h>
 
 #include <kofficeversion.h>
