@@ -23,7 +23,9 @@
 #include <KoFilter.h>
 
 class WRIDevice;
-class MSWrite::InternalParser;
+namespace MSWrite {
+    class InternalParser;
+}
 class KWordGenerator;
 
 class MSWriteImport : public KoFilter
