@@ -28,10 +28,10 @@ class VTool;
 class VToolBox : public KoToolBox
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
-	VToolBox( KMainWindow *mainWin, const char* name, KInstance* instance );
+	VToolBox( TDEMainWindow *mainWin, const char* name, TDEInstance* instance );
 	virtual ~VToolBox() {}
 
 	void registerTool( VTool * );
