@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
    */
 
@@ -132,16 +132,16 @@ class KDChartParams;
 class KDCHART_EXPORT KDChartAxisParams : public TQObject
 {
     Q_OBJECT
-    TQ_OBJECT
-    Q_ENUMS(AxisType)
-    Q_ENUMS(AxisPos)
-    Q_ENUMS(AxisAreaMode)
-    Q_ENUMS(AxisCalcMode)
-    Q_ENUMS(LabelsFromDataRow)
-    Q_ENUMS(ValueScale)
+    
+    TQ_ENUMS(AxisType)
+    TQ_ENUMS(AxisPos)
+    TQ_ENUMS(AxisAreaMode)
+    TQ_ENUMS(AxisCalcMode)
+    TQ_ENUMS(LabelsFromDataRow)
+    TQ_ENUMS(ValueScale)
 
     // Neede by TQSA
-    Q_ENUMS( PenStyle )
+    TQ_ENUMS( PenStyle )
 
 public:
 
