@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
    */
 
@@ -87,13 +87,13 @@
 class KDCHART_EXPORT KDFrame : public TQObject
 {
     Q_OBJECT
-  TQ_OBJECT
-    Q_ENUMS( BackPixmapMode )
-    Q_ENUMS( SimpleFrame )
-    Q_ENUMS( ProfileName )
-    Q_ENUMS( CornerName )
-    Q_ENUMS( CornerStyle )
-    Q_ENUMS( KDFramePaintSteps )
+  
+    TQ_ENUMS( BackPixmapMode )
+    TQ_ENUMS( SimpleFrame )
+    TQ_ENUMS( ProfileName )
+    TQ_ENUMS( CornerName )
+    TQ_ENUMS( CornerStyle )
+    TQ_ENUMS( KDFramePaintSteps )
 
 public:
     //// GENERAL
