@@ -38,7 +38,7 @@
 #include <tqtimer.h>
 
 #include <kdebug.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
 
 KexiDialogBase::KexiDialogBase(KexiMainWindow *parent, const TQString &caption)
@@ -134,7 +134,7 @@ TQSize KexiDialogBase::sizeHint() const
 }
 
 /*
-KInstance *KexiDialogBase::instance() {
+TDEInstance *KexiDialogBase::instance() {
 	return m_instance;
 }*/
 
