@@ -23,12 +23,12 @@
 #include <tqstrlist.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klibloader.h>
-#include <kparts/componentfactory.h>
+#include <tdeparts/componentfactory.h>
 #include <ktrader.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 #include "widgetfactory.h"
 #include "widgetlibrary.h"
@@ -195,8 +195,8 @@ WidgetLibrary::loadFactoryWidgets(WidgetFactory *f)
 void
 WidgetLibrary::lookupFactories()
 {
-	KTrader::OfferList tlist = KTrader::self()->query("KFormDesigner/WidgetFactory");
-	KTrader::OfferList::ConstIterator it, end( tlist.constEnd() );
+	TDETrader::OfferList tlist = TDETrader::self()->query("KFormDesigner/WidgetFactory");
+	TDETrader::OfferList::ConstIterator it, end( tlist.constEnd() );
 	for( it = tlist.constBegin(); it != end; ++it)
 	{
 		KService::Ptr ptr = (*it);
@@ -217,7 +217,7 @@ WidgetLibrary::lookupFactories()
 		}
 		const uint factoryVersion = ptr->property("X-KFormDesigner-WidgetFactoryVersion").toUInt();
 		if (KFormDesigner::version()!=factoryVersion) {
-			kdWarning() << TQString("WidgetLibrary::lookupFactories(): factory '%1'" 
+			kdWarning() << TQString("WidgetLibrary::lookupFactories(): factory '%1'"
 				" has version '%2' but required Widget Factory version is '%3'\n"
 				" -- skipping this factory!").arg(ptr->library()).arg(factoryVersion)
 				.arg(KFormDesigner::version()) << endl;
@@ -319,7 +319,7 @@ WidgetLibrary::createXML()
 }*/
 
 ActionList
-WidgetLibrary::createWidgetActions(KXMLGUIClient* client, KActionCollection *parent, 
+WidgetLibrary::createWidgetActions(KXMLGUIClient* client, TDEActionCollection *parent,
 	TQObject *receiver, const char *slot)
 {
 	loadFactories();
@@ -338,8 +338,8 @@ WidgetLibrary::createWidgetActions(KXMLGUIClient* client, KActionCollection *par
 	ActionList actions;
 	for (TQAsciiDictIterator<WidgetInfo> it(d->widgets); it.current(); ++it)
 	{
-		LibActionWidget *a = new LibActionWidget(it.current(), 
-			it.current()->factory()->m_guiClient 
+		LibActionWidget *a = new LibActionWidget(it.current(),
+			it.current()->factory()->m_guiClient
 			? it.current()->factory()->m_guiClient->actionCollection() : parent);
 		connect(a, TQT_SIGNAL(prepareInsert(const TQCString &)), receiver, slot);
 		actions.append(a);
@@ -348,12 +348,12 @@ WidgetLibrary::createWidgetActions(KXMLGUIClient* client, KActionCollection *par
 }
 
 void
-WidgetLibrary::addCustomWidgetActions(KActionCollection *col)
+WidgetLibrary::addCustomWidgetActions(TDEActionCollection *col)
 {
 	for (TQAsciiDictIterator<WidgetFactory> it(d->factories); it.current(); ++it)
 	{
 		it.current()->createCustomActions(
-			it.current()->m_guiClient 
+			it.current()->m_guiClient
 			? it.current()->m_guiClient->actionCollection() : col);
 	}
 }
@@ -730,15 +730,15 @@ WidgetFactory::CreateWidgetOptions WidgetLibrary::showOrientationSelectionPopup(
 	if (textHorizontal.isEmpty() && wclass->inheritedClass())
 		iconName = wclass->inheritedClass()->factory()->internalProperty(classname, "orientationSelectionPopup:horizontalText");
 	if (textHorizontal.isEmpty()) //default
-		textHorizontal = i18n("InsertQt::Horizontal Widget", "InsertQt::Horizontal");
+		textHorizontal = i18n("Insert Horizontal Widget", "Insert Horizontal");
 
 	TQString textVertical = wclass->factory()->internalProperty(classname, "orientationSelectionPopup:verticalText");
 	if (textVertical.isEmpty() && wclass->inheritedClass())
 		iconName = wclass->inheritedClass()->factory()->internalProperty(classname, "orientationSelectionPopup:verticalText");
 	if (textVertical.isEmpty()) //default
-		textVertical = i18n("InsertQt::Vertical Widget", "InsertQt::Vertical");
+		textVertical = i18n("Insert Vertical Widget", "Insert Vertical");
 
-	KPopupMenu* popup = new KPopupMenu(parent, "orientationSelectionPopup");
+	TDEPopupMenu* popup = new TDEPopupMenu(parent, "orientationSelectionPopup");
 	popup->insertTitle(SmallIcon(wclass->pixmap()), i18n("Insert Widget: %1").arg(wclass->name()));
 	popup->insertItem(iconHorizontal, textHorizontal, 1);
 	popup->insertItem(iconVertical, textVertical, 2);
