@@ -28,9 +28,9 @@
 #include <tqapplication.h>
 #include <tqeventloop.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include "objecttree.h"
 #include "form.h"
