@@ -36,21 +36,21 @@
 #include <tqtooltip.h>
 #include <tqwidgetstack.h>
 
-#include <klocale.h>
-#include <kdeversion.h>
+#include <tdelocale.h>
+#include <tdeversion.h>
 #include <kinstance.h>
 #include <kdebug.h>
 #include <kpushbutton.h>
 #include <kjanuswidget.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <ktextedit.h>
-#include <kfileiconview.h>
-#include <kfileitem.h>
-#include <kmessagebox.h>
-#include <kapplication.h>
+#include <tdefileiconview.h>
+#include <tdefileitem.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
 #include <kmimetype.h>
 #include <ktextbrowser.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 #ifdef KEXI_SHOW_UNIMPLEMENTED
 #define KEXI_STARTUP_SHOW_TEMPLATES
@@ -69,9 +69,9 @@ public:
 		result = 0;
 		TQString none, iconname;
 		iconname = KMimeType::mimeType( KexiDB::Driver::defaultFileBasedDriverMimeType() )->icon(none,0);
-		kexi_sqlite_icon = KGlobal::iconLoader()->loadIcon( iconname, KIcon::Desktop );
+		kexi_sqlite_icon = TDEGlobal::iconLoader()->loadIcon( iconname, TDEIcon::Desktop );
 		iconname = KMimeType::mimeType("application/x-kexiproject-shortcut")->icon(none,0);
-		kexi_shortcut_icon = KGlobal::iconLoader()->loadIcon( iconname, KIcon::Desktop );
+		kexi_shortcut_icon = TDEGlobal::iconLoader()->loadIcon( iconname, TDEIcon::Desktop );
 		prj_selector = 0;
 		chkDoNotShow = 0;
 		openExistingConnWidget = 0;
@@ -142,7 +142,7 @@ TQString captionForDialogType(int type)
 }
 
 /*================================================================*/
-/*KexiStartupDialog::KexiStartupDialog(TQWidget *parent, const char *name, KInstance* global,
+/*KexiStartupDialog::KexiStartupDialog(TQWidget *parent, const char *name, TDEInstance* global,
 	const TQCString &format, const TQString &nativePattern,
 	const TQString &nativeName, const DialogType &dialogType,
 	const TQCString& templateType) :
@@ -166,7 +166,7 @@ KexiStartupDialog::KexiStartupDialog(
  	d->singlePage = dlgSinglePage(dialogType);
 
 	if (dialogType==OpenExisting) {//this dialog has "open" tab only!
-		setIcon(DesktopIcon("fileopen"));
+		setIcon(DesktopIcon("document-open"));
 	} else {
 		setIcon(d->kexi_sqlite_icon);
 	}
@@ -208,8 +208,8 @@ KexiStartupDialog::~KexiStartupDialog()
 
 bool KexiStartupDialog::shouldBeShown()
 {
-	KGlobal::config()->setGroup("Startup");
-	return KGlobal::config()->readBoolEntry("ShowStartupDialog",true);
+	TDEGlobal::config()->setGroup("Startup");
+	return TDEGlobal::config()->readBoolEntry("ShowStartupDialog",true);
 }
 
 void KexiStartupDialog::show()
@@ -272,15 +272,15 @@ void KexiStartupDialog::done(int r)
 	}
 
 	//save settings
-	KGlobal::config()->setGroup("Startup");
+	TDEGlobal::config()->setGroup("Startup");
 	if (d->openExistingConnWidget)
-		KGlobal::config()->writeEntry("OpenExistingType", 
+		TDEGlobal::config()->writeEntry("OpenExistingType", 
 		(d->openExistingConnWidget->selectedConnectionType() == KexiConnSelectorWidget::FileBased) 
 			? "File" : "Server");
 	if (d->chkDoNotShow)
-		KGlobal::config()->writeEntry("ShowStartupDialog",!d->chkDoNotShow->isChecked());
+		TDEGlobal::config()->writeEntry("ShowStartupDialog",!d->chkDoNotShow->isChecked());
 
-	KGlobal::config()->sync();
+	TDEGlobal::config()->sync();
 
 	KDialogBase::done(r);
 }
@@ -299,7 +299,7 @@ void KexiStartupDialog::setupPageTemplates()
 	d->templatesWidget = new KJanusWidget(
 		d->pageTemplates, "templatesWidget", KJanusWidget::IconList);
 	{//aaa! dirty hack
-		d->templatesWidget_IconListBox = d->templatesWidget->child(0,"KListBox");
+		d->templatesWidget_IconListBox = d->templatesWidget->child(0,"TDEListBox");
 		if (d->templatesWidget_IconListBox)
 			d->templatesWidget_IconListBox->installEventFilter(this);
 	}
@@ -320,7 +320,7 @@ void KexiStartupDialog::setupPageTemplates()
 	d->templatesSectionID_blank = itemID++;
 	TQString clickMsg( "\n\n" + i18n("Click \"OK\" button to proceed.") );
 	templPageFrame = d->templatesWidget->addPage(
-		i18n("Blank Database"), i18n("New Blank Database Project"), DesktopIcon("empty") );
+		i18n("Blank Database"), i18n("New Blank Database Project"), DesktopIcon("application-x-zerosize") );
 	tmplyr = new TQVBoxLayout(templPageFrame, 0, KDialogBase::spacingHint());
 	TQLabel *lbl_blank = new TQLabel( 
 		i18n("Kexi will create a new blank database project.")+clickMsg, templPageFrame );
@@ -398,7 +398,7 @@ void KexiStartupDialog::setupPageTemplates()
 void KexiStartupDialog::slotPageShown(TQWidget *page)
 {
 	int idx = d->templatesWidget->pageIndex(page);
-//	KIconView *templ = 0;
+//	TDEIconView *templ = 0;
 	if (idx==d->templatesSectionID_blank) {//blank
 //		kdDebug() << "blank" << endl;
 	}
@@ -408,12 +408,12 @@ void KexiStartupDialog::slotPageShown(TQWidget *page)
 	else if (idx==d->templatesSectionID_templates) {
 		d->viewTemplates->populate();
 	}
-/*later?		KIconView *templ = d->viewTemplates->templates;
+/*later?		TDEIconView *templ = d->viewTemplates->templates;
 		if (templ->count()==0) {
 			//add items (on demand):
 			d->viewTemplates->addItem("cd_catalog", i18n("CD Catalog"),
 				i18n("Easy-to-use database for storing information about your CD collection."),
-				DesktopIcon("cdrom_unmount"));
+				DesktopIcon("media-optical-cdrom"));
 			d->viewTemplates->addItem("expenses", i18n("Expenses"),
 				i18n("A database for managing your personal expenses."),
 				DesktopIcon("kcalc"));
@@ -552,7 +552,7 @@ void KexiStartupDialog::setupPageOpenExisting()
 		d->pageOpenExisting, "KexiConnSelectorWidget");
 	d->openExistingConnWidget->hideConnectonIcon();
 	lyr->addWidget( d->openExistingConnWidget );
-	if (KGlobal::config()->readEntry("OpenExistingType","File")=="File")
+	if (TDEGlobal::config()->readEntry("OpenExistingType","File")=="File")
 		d->openExistingConnWidget->showSimpleConn();
 	else {
 		d->openExistingConnWidget->showSimpleConn();
