@@ -42,7 +42,7 @@ public:
 	 - SavingServerBasedDB saves server-based (shortcut) file
 	 - CustomOpening can be used for opening other files, like CSV
 	*/
-	typedef enum Mode { 
+	enum Mode {
 		Opening = 1,
 		SavingFileBasedDB = 2,
 		SavingServerBasedDB = 4,
