@@ -31,16 +31,16 @@
 #include <tqpainter.h>
 
 #include <kdebug.h>
-#include <kpopupmenu.h>
-#include <klocale.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kimageio.h>
 #include <kstandarddirs.h>
 #include <kstaticdeleter.h>
 #include <kimageeffect.h>
-#include <kstdaccel.h>
-#include <kmessagebox.h>
+#include <tdestdaccel.h>
+#include <tdemessagebox.h>
 #include <kguiitem.h>
 
 #include <widget/utils/kexidropdownbutton.h>
@@ -53,7 +53,7 @@
 
 #ifdef TQ_WS_WIN
 #include <win32_utils.h>
-#include <krecentdirs.h>
+#include <tderecentdirs.h>
 #endif
 
 #include "kexidbutils.h"
@@ -779,7 +779,7 @@ bool KexiDBImageBox::keyPressed(TQKeyEvent *ke)
 			return true;
 		}
 	}
-//	else if (ke->state() == TQt::ControlButton && KStdAccel::shortcut(KStdAccel::Copy).keyCodeTQt() == (ke->key()|TQt::CTRL)) {
+//	else if (ke->state() == TQt::ControlButton && TDEStdAccel::shortcut(TDEStdAccel::Copy).keyCodeTQt() == (ke->key()|TQt::CTRL)) {
 //	}
 	return false;
 }
