@@ -24,7 +24,7 @@
 
 #include <kcombobox.h>
 #include <kpushbutton.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kdebug.h>
 
@@ -47,13 +47,13 @@ class KexiMacroProperty::Private
 		/** The @a KoMacro::MacroItem the custom property uses
 		internal. Together with the name we are able to identify
 		the used variable at runtime. */
-		KSharedPtr<KoMacro::MacroItem> macroitem;
+		TDESharedPtr<KoMacro::MacroItem> macroitem;
 		/** The name the variable @a KoMacro::Variable is known
 		as in the @a KoMacro::MacroItem defined above. */
 		TQString name;
 };
 
-KexiMacroProperty::KexiMacroProperty(KoProperty::Property* parent, KSharedPtr<KoMacro::MacroItem> macroitem, const TQString& name)
+KexiMacroProperty::KexiMacroProperty(KoProperty::Property* parent, TDESharedPtr<KoMacro::MacroItem> macroitem, const TQString& name)
 	: KoProperty::CustomProperty(parent)
 	, d( new Private() )
 {
@@ -72,21 +72,21 @@ void KexiMacroProperty::init()
 	Q_ASSERT( d->macroitem != 0 );
 	//kdDebug() << "--------- KexiMacroProperty::set() macroitem=" << d->macroitem->name() << " name=" << d->name << endl;
 
-	KSharedPtr<KoMacro::Action> action = d->macroitem->action();
-	KSharedPtr<KoMacro::Variable> actionvariable = action->variable(d->name);
+	TDESharedPtr<KoMacro::Action> action = d->macroitem->action();
+	TDESharedPtr<KoMacro::Variable> actionvariable = action->variable(d->name);
 	if(! actionvariable.data()) {
 		kdDebug() << "KexiMacroProperty::createProperty() Skipped cause there exists no such action=" << d->name << endl;
 		return;
 	}
 
-	KSharedPtr<KoMacro::Variable> variable = d->macroitem->variable(d->name, true/*checkaction*/);
+	TDESharedPtr<KoMacro::Variable> variable = d->macroitem->variable(d->name, true/*checkaction*/);
 	if(! variable.data()) {
 		kdDebug() << "KexiMacroProperty::createProperty() Skipped cause there exists no such variable=" << d->name << endl;
 		return;
 	}
 
 	//TESTCASE!!!!!!!!!!!!!!!!!!!!!!
-	//if(! variable->isEnabled()) qFatal( TQString("############## VARIABLE=%1").arg(variable->name()).latin1() );
+	//if(! variable->isEnabled()) tqFatal( TQString("############## VARIABLE=%1").arg(variable->name()).latin1() );
 
 	Q_ASSERT(! d->name.isNull());
 	m_property->setName( d->name.latin1() );
@@ -121,7 +121,7 @@ void KexiMacroProperty::setValue(const TQVariant &value, bool rememberOldValue)
 
 TQVariant KexiMacroProperty::value() const
 {
-	KSharedPtr<KoMacro::Variable> variable = d->macroitem->variable(d->name, true);
+	TDESharedPtr<KoMacro::Variable> variable = d->macroitem->variable(d->name, true);
 	Q_ASSERT( variable.data() != 0 );
 	return variable.data() ? variable->variant() : TQVariant();
 }
@@ -131,7 +131,7 @@ bool KexiMacroProperty::handleValue() const
 	return true; // we handle getting and setting of values and don't need KoProperty::Property for it.
 }
 
-KSharedPtr<KoMacro::MacroItem> KexiMacroProperty::macroItem() const
+TDESharedPtr<KoMacro::MacroItem> KexiMacroProperty::macroItem() const
 {
 	return d->macroitem;
 }
@@ -141,12 +141,12 @@ TQString KexiMacroProperty::name() const
 	return d->name;
 }
 
-KSharedPtr<KoMacro::Variable> KexiMacroProperty::variable() const
+TDESharedPtr<KoMacro::Variable> KexiMacroProperty::variable() const
 {
 	return d->macroitem->variable(d->name, true/*checkaction*/);
 }
 
-KoProperty::Property* KexiMacroProperty::createProperty(KSharedPtr<KoMacro::MacroItem> macroitem, const TQString& name)
+KoProperty::Property* KexiMacroProperty::createProperty(TDESharedPtr<KoMacro::MacroItem> macroitem, const TQString& name)
 {
 	KoProperty::Property* property = new KoProperty::Property();
 	KexiMacroProperty* customproperty = new KexiMacroProperty(property, macroitem, name);
@@ -184,7 +184,7 @@ KoProperty::CustomProperty* KexiMacroPropertyFactory::createCustomProperty(KoPro
 		return 0;
 	}
 
-	KSharedPtr<KoMacro::MacroItem> macroitem = parentcustomproperty->macroItem();
+	TDESharedPtr<KoMacro::MacroItem> macroitem = parentcustomproperty->macroItem();
 	Q_ASSERT( macroitem.data() != 0 );
 	const TQString name = parentcustomproperty->name();
 	Q_ASSERT(! name.isEmpty());
@@ -266,7 +266,7 @@ class EditListBoxItem : public ListBoxItem
 		}
 
 		virtual TQString text() const {
-			KSharedPtr<KoMacro::Variable> variable = m_macroproperty->variable();
+			TDESharedPtr<KoMacro::Variable> variable = m_macroproperty->variable();
 			Q_ASSERT( variable.data() );
 			//kdDebug()<<"EditListBoxItem::text() text="<<variable->toString()<<endl;
 			Q_ASSERT( variable->toString() != TQString() );
@@ -274,9 +274,9 @@ class EditListBoxItem : public ListBoxItem
 		}
 
 		KoProperty::Widget* widget() const { return m_widget; }
-		KSharedPtr<KoMacro::MacroItem> macroItem() const { return m_macroproperty->macroItem(); }
-		KSharedPtr<KoMacro::Variable> variable() const { return m_macroproperty->variable(); }
-		KSharedPtr<KoMacro::Action> action() const { return m_macroproperty->macroItem()->action(); }
+		TDESharedPtr<KoMacro::MacroItem> macroItem() const { return m_macroproperty->macroItem(); }
+		TDESharedPtr<KoMacro::Variable> variable() const { return m_macroproperty->variable(); }
+		TDESharedPtr<KoMacro::Action> action() const { return m_macroproperty->macroItem()->action(); }
 
 	protected:
 		virtual void paint(TQPainter* p) {
@@ -290,9 +290,9 @@ class EditListBoxItem : public ListBoxItem
 
 	private:
 		void init() {
-			KSharedPtr<KoMacro::MacroItem> macroitem = m_macroproperty->macroItem();
+			TDESharedPtr<KoMacro::MacroItem> macroitem = m_macroproperty->macroItem();
 			Q_ASSERT( macroitem.data() );
-			KSharedPtr<KoMacro::Action> action = m_macroproperty->macroItem()->action();
+			TDESharedPtr<KoMacro::Action> action = m_macroproperty->macroItem()->action();
 			if(! action.data()) {
 				kdWarning() << "EditListBoxItem::EditListBoxItem() Skipped cause there exists no action for macroproperty=" << m_macroproperty->name() << endl;
 				return;
@@ -302,7 +302,7 @@ class EditListBoxItem : public ListBoxItem
 				kdWarning() << "EditListBoxItem::EditListBoxItem() No parentproperty defined" << endl;
 				return;
 			}
-			KSharedPtr<KoMacro::Variable> variable = m_macroproperty->variable();
+			TDESharedPtr<KoMacro::Variable> variable = m_macroproperty->variable();
 			if(! variable.data()) {
 				kdWarning() << "EditListBoxItem::EditListBoxItem() No variable defined for property=" << parentproperty->name() << endl;
 				return;
@@ -310,7 +310,7 @@ class EditListBoxItem : public ListBoxItem
 
 			TQVariant variant = variable->variant();
 
-			KSharedPtr<KoMacro::Variable> actionvariable = action->variable(m_macroproperty->name());
+			TDESharedPtr<KoMacro::Variable> actionvariable = action->variable(m_macroproperty->name());
 			if(actionvariable.data()) {
 				TQVariant actionvariant = actionvariable->variant();
 				Q_ASSERT( ! actionvariant.isNull() );
@@ -393,13 +393,13 @@ class ListBox : public TQListBox
 			{
 				KoMacro::Variable::List actionchildren;
 
-				KSharedPtr<KoMacro::Variable> itemvar = m_macroproperty->macroItem()->variable(name,false);
+				TDESharedPtr<KoMacro::Variable> itemvar = m_macroproperty->macroItem()->variable(name,false);
 				//kdDebug() << "KexiMacroProperty::ListBox::update() itemvar="<<(itemvar.data() ? "name:"+itemvar->name()+" value:"+itemvar->toString() : "NULL")<<endl;
 				if(itemvar.data())
 					actionchildren = itemvar->children();
 
-				KSharedPtr<KoMacro::Action> action = m_edititem->action();
-				KSharedPtr<KoMacro::Variable> actionvar = action.data() ? action->variable(name) : KSharedPtr<KoMacro::Variable>();
+				TDESharedPtr<KoMacro::Action> action = m_edititem->action();
+				TDESharedPtr<KoMacro::Variable> actionvar = action.data() ? action->variable(name) : TDESharedPtr<KoMacro::Variable>();
 				//kdDebug() << "KexiMacroProperty::ListBox::update() actionvar="<<(actionvar.data() ? "name:"+actionvar->name()+" value:"+actionvar->toString() : "NULL")<<endl;
 				if(actionvar.data())
 					actionchildren += actionvar->children();
