@@ -24,9 +24,9 @@
 #include <tqvbox.h>
 #include <tqtimer.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
 
 #include <kexiutils/utils.h>
@@ -79,7 +79,7 @@ class KexiQueryDesignerSQLView::Private
 		KexiSectionHeader *head, *historyHead;
 		TQPixmap statusPixmapOk, statusPixmapErr, statusPixmapInfo;
 		TQSplitter *splitter;
-		KToggleAction *action_toggle_history;
+		TDEToggleAction *action_toggle_history;
 		//! For internal use, this pointer is usually copied to TempData structure, 
 		//! when switching out of this view (then it's cleared).
 		KexiDB::QuerySchema *parsedQuery;
@@ -138,7 +138,7 @@ KexiQueryDesignerSQLView::KexiQueryDesignerSQLView(KexiMainWindow *mainWin, TQWi
 
 	plugSharedAction("querypart_check_query", TQT_TQOBJECT(this), TQT_SLOT(slotCheckQuery())); 
 	plugSharedAction("querypart_view_toggle_history", TQT_TQOBJECT(this), TQT_SLOT(slotUpdateMode()));
-	d->action_toggle_history = static_cast<KToggleAction*>( sharedAction( "querypart_view_toggle_history" ) );
+	d->action_toggle_history = static_cast<TDEToggleAction*>( sharedAction( "querypart_view_toggle_history" ) );
 
 	d->historyHead = new KexiSectionHeader(i18n("SQL Query History"),Qt::Vertical, d->history_section);
 	d->historyHead->installEventFilter(this);
@@ -147,9 +147,9 @@ KexiQueryDesignerSQLView::KexiQueryDesignerSQLView(KexiMainWindow *mainWin, TQWi
 	static const TQString msg_back = i18n("Back to Selected Query");
 	static const TQString msg_clear = i18n("Clear History");
 	d->historyHead->addButton("select_item", msg_back, TQT_TQOBJECT(this), TQT_SLOT(slotSelectQuery()));
-	d->historyHead->addButton("editclear", msg_clear, TQT_TQOBJECT(d->history), TQT_SLOT(clear()));
+	d->historyHead->addButton("edit-clear", msg_clear, TQT_TQOBJECT(d->history), TQT_SLOT(clear()));
 	d->history->popupMenu()->insertItem(SmallIcon("select_item"), msg_back, TQT_TQOBJECT(this), TQT_SLOT(slotSelectQuery()));
-	d->history->popupMenu()->insertItem(SmallIcon("editclear"), msg_clear, d->history, TQT_SLOT(clear()));
+	d->history->popupMenu()->insertItem(SmallIcon("edit-clear"), msg_clear, d->history, TQT_SLOT(clear()));
 	connect(d->history, TQT_SIGNAL(currentItemDoubleClicked()), TQT_TQOBJECT(this), TQT_SLOT(slotSelectQuery()));
 
 	d->heightForHistoryMode = -1; //height() / 2;
