@@ -28,10 +28,10 @@
 
 #include <kiconloader.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kaction.h>
-#include <kpopupmenu.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeaction.h>
+#include <tdepopupmenu.h>
+#include <tdemessagebox.h>
 #include <kiconeffect.h>
 
 #include <koproperty/set.h>
@@ -122,9 +122,9 @@ KexiTableDesignerView::KexiTableDesignerView(KexiMainWindow *win, TQWidget *pare
 
 	KexiTableViewColumn *col = new KexiTableViewColumn("pk", KexiDB::Field::Text, TQString(),
 		i18n("Additional information about the field"));
-	col->setIcon( KexiUtils::colorizeIconToTextColor( SmallIcon("info"), d->view->palette() ) );
+	col->setIcon( KexiUtils::colorizeIconToTextColor( SmallIcon("application-vnd.tde.info"), d->view->palette() ) );
 	col->setHeaderTextVisible(false);
-	col->field()->setSubType("KIcon");
+	col->field()->setSubType("TDEIcon");
 	col->setReadOnly(true);
 	d->data->addColumn( col );
 
@@ -175,12 +175,12 @@ KexiTableDesignerView::KexiTableDesignerView(KexiMainWindow *win, TQWidget *pare
 	connect(d->sets, TQT_SIGNAL(rowDeleted()), TQT_TQOBJECT(this), TQT_SLOT(updateActions()));
 	connect(d->sets, TQT_SIGNAL(rowInserted()), TQT_TQOBJECT(this), TQT_SLOT(slotRowInserted()));
 
-	d->contextMenuTitle = new KPopupTitle(d->view->contextMenu());
+	d->contextMenuTitle = new TDEPopupTitle(d->view->contextMenu());
 	d->view->contextMenu()->insertItem(d->contextMenuTitle, -1, 0);
 	connect(d->view->contextMenu(), TQT_SIGNAL(aboutToShow()), TQT_TQOBJECT(this), TQT_SLOT(slotAboutToShowContextMenu()));
 
 	plugSharedAction("tablepart_toggle_pkey", TQT_TQOBJECT(this), TQT_SLOT(slotTogglePrimaryKey()));
-	d->action_toggle_pkey = static_cast<KToggleAction*>( sharedAction("tablepart_toggle_pkey") );
+	d->action_toggle_pkey = static_cast<TDEToggleAction*>( sharedAction("tablepart_toggle_pkey") );
 	d->action_toggle_pkey->plug(d->view->contextMenu(), 1); //add at the beginning
 	d->view->contextMenu()->insertSeparator(2);
 	setAvailable("tablepart_toggle_pkey", !conn->isReadOnly());
@@ -268,7 +268,7 @@ void KexiTableDesignerView::initData()
 	}
 
 	//column widths
-	d->view->setColumnWidth(COLUMN_ID_ICON, IconSize( KIcon::Small ) + 10);
+	d->view->setColumnWidth(COLUMN_ID_ICON, IconSize( TDEIcon::Small ) + 10);
 	d->view->adjustColumnWidthToContents(COLUMN_ID_CAPTION); //adjust column width
 	d->view->setColumnWidth(COLUMN_ID_TYPE, d->maxTypeNameTextWidth + 2 * d->view->rowHeight());
 	d->view->setColumnStretchEnabled( true, COLUMN_ID_DESC ); //last column occupies the rest of the area
