@@ -121,8 +121,7 @@ int main(int argc, char** argv)
 			"(c) 2003-2006, Kexi Team\n"
 			"(c) 2003-2006, OpenOffice Polska Ltd.\n",
 			"",
-			"http://www.koffice.org/kexi",
-			"submit@bugs.kde.org"
+			"bugs.trinitydesktop.org"
 		)
 	);
 	TDECmdLineArgs::addCmdLineOptions( options );
