@@ -34,8 +34,8 @@
 #include "kivio_pluginmanager.h"
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kcursor.h>
 #include <KoGlobal.h>
 #include <KoZoomHandler.h>
@@ -43,7 +43,7 @@
 #include <KoRuler.h>
 #include <KoPoint.h>
 #include <KoTabBar.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include <assert.h>
 #include <stdio.h>
@@ -275,7 +275,7 @@ void KivioCanvas::paintEvent( TQPaintEvent* ev )
   painter.save();
   painter.setClipRegion(grayRegion, TQPainter::CoordPainter);
   painter.setPen(TQt::NoPen);
-  painter.fillRect(grayRegion.boundingRect(), KApplication::palette().active().brush(TQColorGroup::Mid));
+  painter.fillRect(grayRegion.boundingRect(), TDEApplication::palette().active().brush(TQColorGroup::Mid));
   painter.restore();
   // end of copy...
 
