@@ -43,20 +43,20 @@
 #include <tqstringlist.h>
 #include <tqstrlist.h>
 #include <tqimage.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 
 #include <kdialogbase.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcolorbutton.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kstdaccel.h>
+#include <tdestdaccel.h>
 #include <kstdaction.h>
-#include <kglobal.h>
-#include <kmessagebox.h>
+#include <tdeglobal.h>
+#include <tdemessagebox.h>
 #include <kdebug.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kstatusbar.h>
 #include <kinputdialog.h>
 #include <knotifyclient.h>
@@ -64,7 +64,7 @@
 #include <dcopclient.h>
 #include <dcopref.h>
 
-#include <kparts/event.h>
+#include <tdeparts/event.h>
 #include <KoPartSelectDia.h>
 #include <KoQueryTrader.h>
 #include <KoPageLayoutDia.h>
@@ -128,7 +128,7 @@
 #include "objectlistpalette.h"
 #include "addstencilsetdialog.h"
 
-#define TOGGLE_ACTION(X) ((KToggleAction*)actionCollection()->action(X))
+#define TOGGLE_ACTION(X) ((TDEToggleAction*)actionCollection()->action(X))
 #define MOUSEPOS_TEXT 1000
 #define PAGECOUNT_TEXT 0
 #define INFO_TEXT 1
@@ -163,8 +163,8 @@ KivioView::KivioView( TQWidget *_parent, const char *_name, KivioDoc* doc )
     TQString unit = KoUnit::unitName(m_pDoc->unit());
     KoPoint xy(0, 0);
     TQString text = i18n("%1 x coord, %2 y coord, %3 and %4 the unit",
-                        "X: %1 %3 Y: %2 %4").arg(KGlobal::_locale->formatNumber(xy.x(), 2))
-                        .arg(KGlobal::_locale->formatNumber(xy.y(), 2)).arg(unit).arg(unit);
+                        "X: %1 %3 Y: %2 %4").arg(TDEGlobal::_locale->formatNumber(xy.x(), 2))
+                        .arg(TDEGlobal::_locale->formatNumber(xy.y(), 2)).arg(unit).arg(unit);
     m_coordSLbl = new KStatusBarLabel(text, MOUSEPOS_TEXT, sb);
     addStatusBarItem(m_coordSLbl, 0, true);
   }
@@ -384,7 +384,7 @@ void KivioView::setupActions()
   connect(TQT_TQOBJECT(this), TQT_SIGNAL(updateStencilSetList()), addStSet, TQT_SLOT(updateMenu()));
   connect(addStSet, TQT_SIGNAL(showDialog()), TQT_TQOBJECT(this), TQT_SLOT(showAddStencilSetDialog()));
 
-  m_alignAndDistribute = new KAction( i18n("Align && Distribute..."), CTRL+ALT+Key_A, TQT_TQOBJECT(this),
+  m_alignAndDistribute = new TDEAction( i18n("Align && Distribute..."), CTRL+ALT+Key_A, TQT_TQOBJECT(this),
     TQT_SLOT(alignStencilsDlg()), actionCollection(), "alignStencils" );
 
   m_editCut = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT(cutStencil()), actionCollection(), "cutStencil" );
@@ -395,71 +395,71 @@ void KivioView::setupActions()
   m_selectAll = KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(selectAllStencils()), actionCollection(), "selectAllStencils");
   m_selectNone = KStdAction::deselect(TQT_TQOBJECT(this), TQT_SLOT(unselectAllStencils()), actionCollection(), "unselectAllStencils");
 
-  m_groupAction = new KAction( i18n("Group Selection"), "group", CTRL+Key_G, TQT_TQOBJECT(this), TQT_SLOT(groupStencils()), actionCollection(), "groupStencils" );
+  m_groupAction = new TDEAction( i18n("Group Selection"), "group", CTRL+Key_G, TQT_TQOBJECT(this), TQT_SLOT(groupStencils()), actionCollection(), "groupStencils" );
   m_groupAction->setWhatsThis(i18n("Group selected objects into a single stencil"));
-  m_ungroupAction = new KAction( i18n("Ungroup"), "ungroup", CTRL+SHIFT+Key_G, TQT_TQOBJECT(this), TQT_SLOT(ungroupStencils()), actionCollection(), "ungroupStencils" );
+  m_ungroupAction = new TDEAction( i18n("Ungroup"), "ungroup", CTRL+SHIFT+Key_G, TQT_TQOBJECT(this), TQT_SLOT(ungroupStencils()), actionCollection(), "ungroupStencils" );
   m_ungroupAction->setWhatsThis(i18n("Break up a selected group stencil"));
 
-  m_stencilToFront = new KAction( i18n("Bring to Front"), "bring_forward", 0, TQT_TQOBJECT(this), TQT_SLOT(bringStencilToFront()), actionCollection(), "bringStencilToFront" );
-  m_stencilToBack = new KAction( i18n("Send to Back"), "send_backward", 0, TQT_TQOBJECT(this), TQT_SLOT(sendStencilToBack()), actionCollection(), "sendStencilToBack" );
+  m_stencilToFront = new TDEAction( i18n("Bring to Front"), "bring_forward", 0, TQT_TQOBJECT(this), TQT_SLOT(bringStencilToFront()), actionCollection(), "bringStencilToFront" );
+  m_stencilToBack = new TDEAction( i18n("Send to Back"), "send_backward", 0, TQT_TQOBJECT(this), TQT_SLOT(sendStencilToBack()), actionCollection(), "sendStencilToBack" );
 
-  m_menuTextFormatAction = new KAction(i18n("&Text..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(textFormat()),
+  m_menuTextFormatAction = new TDEAction(i18n("&Text..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(textFormat()),
   actionCollection(), "textFormat");
 
-  m_menuStencilConnectorsAction = new KAction(i18n("&Stencils && Connectors..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(stencilFormat()),
+  m_menuStencilConnectorsAction = new TDEAction(i18n("&Stencils && Connectors..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(stencilFormat()),
   actionCollection(), "stencilFormat");
 
-  m_arrowHeadsMenuAction = new KAction(i18n("&Arrowheads..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(arrowHeadFormat()),
+  m_arrowHeadsMenuAction = new TDEAction(i18n("&Arrowheads..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(arrowHeadFormat()),
   actionCollection(), "arrowHeadFormat");
   m_arrowHeadsMenuAction->setWhatsThis(i18n("Arrowheads allow you to add an arrow to the beginning and/or end of a line."));
 
   /* Create the fg color button */
-  m_setFGColor = new TKSelectColorAction( i18n("Line Color"), TKSelectColorAction::LineColor, actionCollection(), "setFGColor" );
+  m_setFGColor = new TTDESelectColorAction( i18n("Line Color"), TTDESelectColorAction::LineColor, actionCollection(), "setFGColor" );
   m_setFGColor->setWhatsThis(i18n("The line color allows you to choose a color for the lines of the stencils."));
   connect(m_setFGColor,TQT_SIGNAL(activated()),TQT_SLOT(setFGColor()));
-  m_setBGColor = new TKSelectColorAction( i18n("Fill Color"), TKSelectColorAction::FillColor, actionCollection(), "setBGColor" );
+  m_setBGColor = new TTDESelectColorAction( i18n("Fill Color"), TTDESelectColorAction::FillColor, actionCollection(), "setBGColor" );
   m_setBGColor->setWhatsThis(i18n("You can choose a color for the background of a stencil by using this button."));
   connect(m_setBGColor,TQT_SIGNAL(activated()),TQT_SLOT(setBGColor()));
 
   // Text bar
-  m_setFontFamily = new KFontAction( i18n( "Font Family" ), 0, actionCollection(), "setFontFamily" );
+  m_setFontFamily = new TDEFontAction( i18n( "Font Family" ), 0, actionCollection(), "setFontFamily" );
   connect( m_setFontFamily, TQT_SIGNAL(activated(const TQString&)), TQT_SLOT(setFontFamily(const TQString&)) );
 
-  m_setFontSize = new KFontSizeAction( i18n( "Font Size" ), 0, actionCollection(), "setFontSize" );
+  m_setFontSize = new TDEFontSizeAction( i18n( "Font Size" ), 0, actionCollection(), "setFontSize" );
   connect( m_setFontSize, TQT_SIGNAL( fontSizeChanged( int ) ),
            TQT_TQOBJECT(this), TQT_SLOT( setFontSize(int ) ) );
 
 
-  m_setTextColor = new TKSelectColorAction( i18n("Text Color"), TKSelectColorAction::TextColor, actionCollection(), "setTextColor" );
+  m_setTextColor = new TTDESelectColorAction( i18n("Text Color"), TTDESelectColorAction::TextColor, actionCollection(), "setTextColor" );
   connect( m_setTextColor, TQT_SIGNAL(activated()), TQT_SLOT(setTextColor()) );
 
-  m_setBold = new KToggleAction( i18n("Toggle Bold Text"), "text_bold", 0, actionCollection(), "setFontBold" );
+  m_setBold = new TDEToggleAction( i18n("Toggle Bold Text"), "format-text-bold", 0, actionCollection(), "setFontBold" );
   connect( m_setBold, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleFontBold(bool)) );
 
-  m_setItalics = new KToggleAction( i18n("Toggle Italics Text"), "text_italic", 0, actionCollection(), "setFontItalics" );
+  m_setItalics = new TDEToggleAction( i18n("Toggle Italics Text"), "format-text-italic", 0, actionCollection(), "setFontItalics" );
   connect( m_setItalics, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleFontItalics(bool)) );
 
-  m_setUnderline = new KToggleAction( i18n("Toggle Underline Text"), "text_under", 0, actionCollection(), "setFontUnderline" );
+  m_setUnderline = new TDEToggleAction( i18n("Toggle Underline Text"), "format-text-underline", 0, actionCollection(), "setFontUnderline" );
   connect( m_setUnderline, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleFontUnderline(bool)));
 
-  m_textAlignLeft = new KToggleAction( i18n( "Align &Left" ), "text_left", CTRL + Key_L,
+  m_textAlignLeft = new TDEToggleAction( i18n( "Align &Left" ), "format-text-direction-ltr", CTRL + Key_L,
                                     TQT_TQOBJECT(this), TQT_SLOT( textAlignLeft() ),
                                     actionCollection(), "textAlignLeft" );
   m_textAlignLeft->setExclusiveGroup( "align" );
-  m_textAlignCenter = new KToggleAction( i18n( "Align &Center" ), "text_center", CTRL + ALT + Key_C,
+  m_textAlignCenter = new TDEToggleAction( i18n( "Align &Center" ), "text_center", CTRL + ALT + Key_C,
                                       TQT_TQOBJECT(this), TQT_SLOT( textAlignCenter() ),
                                       actionCollection(), "textAlignCenter" );
   m_textAlignCenter->setExclusiveGroup( "align" );
   m_textAlignCenter->setChecked( TRUE );
-  m_textAlignRight = new KToggleAction( i18n( "Align &Right" ), "text_right", CTRL + ALT + Key_R,
+  m_textAlignRight = new TDEToggleAction( i18n( "Align &Right" ), "format-text-direction-rtl", CTRL + ALT + Key_R,
                                       TQT_TQOBJECT(this), TQT_SLOT( textAlignRight() ),
                                       actionCollection(), "textAlignRight" );
   m_textAlignRight->setExclusiveGroup( "align" );
-  m_textVAlignSuper = new KToggleAction( i18n( "Superscript" ), "super", 0,
+  m_textVAlignSuper = new TDEToggleAction( i18n( "Superscript" ), "super", 0,
                                             TQT_TQOBJECT(this), TQT_SLOT( textSuperScript() ),
                                             actionCollection(), "textVAlignSuper" );
   m_textVAlignSuper->setExclusiveGroup( "valign" );
-  m_textVAlignSub = new KToggleAction( i18n( "Subscript" ), "sub", 0,
+  m_textVAlignSub = new TDEToggleAction( i18n( "Subscript" ), "sub", 0,
                                             TQT_TQOBJECT(this), TQT_SLOT( textSubScript() ),
                                             actionCollection(), "textVAlignSub" );
   m_textVAlignSub->setExclusiveGroup( "valign" );
@@ -472,41 +472,41 @@ void KivioView::setupActions()
   m_lineStyleAction = new KoLineStyleAction(i18n("Line Style"), "linestyle", TQT_TQOBJECT(this), TQT_SLOT(setLineStyle(int)),
     actionCollection(), "setLineStyle");
 
-  m_paperLayout = new KAction( i18n("Page Layout..."), 0, TQT_TQOBJECT(this), TQT_SLOT(paperLayoutDlg()), actionCollection(), "paperLayout" );
-  m_insertPage = new KAction( i18n("Insert Page"),"item_add", 0, TQT_TQOBJECT(this), TQT_SLOT(insertPage()), actionCollection(), "insertPage" );
-  m_removePage = new KAction( i18n("Remove Page"), "item_remove",0,TQT_TQOBJECT(this), TQT_SLOT(removePage()), actionCollection(), "removePage" );
+  m_paperLayout = new TDEAction( i18n("Page Layout..."), 0, TQT_TQOBJECT(this), TQT_SLOT(paperLayoutDlg()), actionCollection(), "paperLayout" );
+  m_insertPage = new TDEAction( i18n("Insert Page"),"item_add", 0, TQT_TQOBJECT(this), TQT_SLOT(insertPage()), actionCollection(), "insertPage" );
+  m_removePage = new TDEAction( i18n("Remove Page"), "item_remove",0,TQT_TQOBJECT(this), TQT_SLOT(removePage()), actionCollection(), "removePage" );
 
-  m_renamePage = new KAction( i18n("Rename Page..."), "item_rename",0,TQT_TQOBJECT(this), TQT_SLOT(renamePage()), actionCollection(), "renamePage" );
+  m_renamePage = new TDEAction( i18n("Rename Page..."), "item_rename",0,TQT_TQOBJECT(this), TQT_SLOT(renamePage()), actionCollection(), "renamePage" );
 
-  m_showPage = new KAction( i18n("Show Page..."),0 ,TQT_TQOBJECT(this),TQT_SLOT(showPage()), actionCollection(), "showPage" );
-  m_hidePage = new KAction( i18n("Hide Page"),0 ,TQT_TQOBJECT(this),TQT_SLOT(hidePage()), actionCollection(), "hidePage" );
+  m_showPage = new TDEAction( i18n("Show Page..."),0 ,TQT_TQOBJECT(this),TQT_SLOT(showPage()), actionCollection(), "showPage" );
+  m_hidePage = new TDEAction( i18n("Hide Page"),0 ,TQT_TQOBJECT(this),TQT_SLOT(hidePage()), actionCollection(), "hidePage" );
 
-  showPageMargins = new KToggleAction( i18n("Show Page Margins"), "view_margins", 0, actionCollection(), "showPageMargins" );
+  showPageMargins = new TDEToggleAction( i18n("Show Page Margins"), "view_margins", 0, actionCollection(), "showPageMargins" );
   connect( showPageMargins, TQT_SIGNAL(toggled(bool)), TQT_SLOT(togglePageMargins(bool)));
 #if KDE_IS_VERSION(3,2,90)
   showPageMargins->setCheckedState(i18n("Hide Page Margins"));
 #endif
 
-  showRulers = new KToggleAction( i18n("Show Rulers"), "view_ruler", 0, actionCollection(), "showRulers" );
+  showRulers = new TDEToggleAction( i18n("Show Rulers"), "view_ruler", 0, actionCollection(), "showRulers" );
   connect( showRulers, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleShowRulers(bool)));
 #if KDE_IS_VERSION(3,2,90)
   showRulers->setCheckedState(i18n("Hide Rulers"));
 #endif
 
   // Grid actions
-  showGrid = new KToggleAction( i18n("Show Grid"), "view_grid", 0, actionCollection(), "showGrid" );
+  showGrid = new TDEToggleAction( i18n("Show Grid"), "view_grid", 0, actionCollection(), "showGrid" );
   connect( showGrid, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleShowGrid(bool)));
 #if KDE_IS_VERSION(3,2,90)
   showGrid->setCheckedState(i18n("Hide Grid"));
 #endif
 
-  KToggleAction* snapGrid = new KToggleAction( i18n("Snap Grid"), "view_grid", 0, actionCollection(), "snapGrid" );
+  TDEToggleAction* snapGrid = new TDEToggleAction( i18n("Snap Grid"), "view_grid", 0, actionCollection(), "snapGrid" );
   connect( snapGrid, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleSnapGrid(bool)));
 
   // Guides actions
-  showGuides = new KToggleAction( i18n("Guide Lines"), 0, actionCollection(), "showGuides" );
+  showGuides = new TDEToggleAction( i18n("Guide Lines"), 0, actionCollection(), "showGuides" );
   connect( showGuides, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleShowGuides(bool)));
-  KAction* addGuide = new KAction(i18n("Add Guide Line..."), 0, TQT_TQOBJECT(this), TQT_SLOT(addGuideLine()),
+  TDEAction* addGuide = new TDEAction(i18n("Add Guide Line..."), 0, TQT_TQOBJECT(this), TQT_SLOT(addGuideLine()),
     actionCollection(), "addGuideLine");
   connect(showGuides, TQT_SIGNAL(toggled(bool)), addGuide, TQT_SLOT(setEnabled(bool)));
   //--
@@ -518,10 +518,10 @@ void KivioView::setupActions()
 
   KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsDialog()), actionCollection(), "options");
 
-  (void) new KAction(i18n("Install Stencil Set..."), 0, TQT_TQOBJECT(this),
+  (void) new TDEAction(i18n("Install Stencil Set..."), 0, TQT_TQOBJECT(this),
     TQT_SLOT(installStencilSet()), actionCollection(), "installStencilSet");
 
-  m_editDelete = new KAction(i18n("Delete"), "editdelete", Key_Delete,
+  m_editDelete = new TDEAction(i18n("Delete"), "edit-delete", Key_Delete,
     TQT_TQOBJECT(this), TQT_SLOT(deleteObject()), actionCollection(), "deleteObject");
 }
 
@@ -561,9 +561,9 @@ void KivioView::initActions()
 
 void KivioView::updateReadWrite( bool readwrite )
 {
-  TQValueList<KAction*> actions = actionCollection()->actions();
-  TQValueList<KAction*>::ConstIterator aIt = actions.begin();
-  TQValueList<KAction*>::ConstIterator aEnd = actions.end();
+  TQValueList<TDEAction*> actions = actionCollection()->actions();
+  TQValueList<TDEAction*>::ConstIterator aIt = actions.begin();
+  TQValueList<TDEAction*>::ConstIterator aEnd = actions.end();
   for (; aIt != aEnd; ++aIt )
     (*aIt)->setEnabled( readwrite );
   if ( !readwrite )
@@ -805,7 +805,7 @@ void KivioView::removePage()
     return;
   }
   TQApplication::beep();
-  int ret = KMessageBox::warningContinueCancel(this,i18n("You are going to remove the active page.\nDo you want to continue?"),i18n("Remove Page"),KGuiItem(i18n("&Delete"),"editdelete"));
+  int ret = KMessageBox::warningContinueCancel(this,i18n("You are going to remove the active page.\nDo you want to continue?"),i18n("Remove Page"),KGuiItem(i18n("&Delete"),"edit-delete"));
 
   if ( ret == KMessageBox::Continue ) {
       KivioPage* tbl = m_pActivePage;
@@ -1568,13 +1568,13 @@ void KivioView::setHParaAlign( int i )
     KivioStencil *pStencil = m_pActivePage->selectedStencils()->first();
     if (!pStencil)
       return;
-    KMacroCommand *macro = new KMacroCommand( i18n("Change StencilQt::Horizontal Alignment"));
+    KMacroCommand *macro = new KMacroCommand( i18n("Change Stencil Horizontal Alignment"));
     bool createMacro = false;
     while( pStencil )
     {
         if ( pStencil->hTextAlign() != i)
         {
-            KivioChangeStencilHAlignmentCommand * cmd = new KivioChangeStencilHAlignmentCommand( i18n("Change StencilQt::Horizontal Alignment"), m_pActivePage, pStencil, pStencil->hTextAlign(), i);
+            KivioChangeStencilHAlignmentCommand * cmd = new KivioChangeStencilHAlignmentCommand( i18n("Change Stencil Horizontal Alignment"), m_pActivePage, pStencil, pStencil->hTextAlign(), i);
 
             pStencil->setHTextAlign(i);
             macro->addCommand( cmd );
@@ -1596,13 +1596,13 @@ void KivioView::setVParaAlign( int i )
     KivioStencil *pStencil = m_pActivePage->selectedStencils()->first();
     if (!pStencil)
       return;
-    KMacroCommand *macro = new KMacroCommand( i18n("Change StencilQt::Vertical Alignment"));
+    KMacroCommand *macro = new KMacroCommand( i18n("Change Stencil Vertical Alignment"));
     bool createMacro = false;
     while( pStencil )
     {
         if ( pStencil->vTextAlign() != i )
         {
-            KivioChangeStencilVAlignmentCommand * cmd = new KivioChangeStencilVAlignmentCommand( i18n("Change StencilQt::Vertical Alignment"), m_pActivePage, pStencil, pStencil->vTextAlign(), i);
+            KivioChangeStencilVAlignmentCommand * cmd = new KivioChangeStencilVAlignmentCommand( i18n("Change Stencil Vertical Alignment"), m_pActivePage, pStencil, pStencil->vTextAlign(), i);
             pStencil->setVTextAlign( i );
             macro->addCommand( cmd );
             createMacro = true;
@@ -1709,7 +1709,7 @@ void KivioView::addStencilFromSpawner( KivioStencilSpawner *pSpawner, double x,
 #if KDE_IS_VERSION(3, 4, 0)
     if(kapp->keyboardMouseState() & TQt::ControlButton) {
 #else
-    if(KApplication::keyboardModifiers() & KApplication::ControlModifier) {
+    if(TDEApplication::keyboardModifiers() & TDEApplication::ControlModifier) {
 #endif
       pStencil->setFGColor(m_setFGColor->color());
       pStencil->setBGColor(m_setBGColor->color());
@@ -1842,8 +1842,8 @@ void KivioView::setMousePos( int mx, int my )
     KoPoint xy = m_pCanvas->mapFromScreen(TQPoint(mx, my));
     xy.setX(KoUnit::toUserValue(xy.x(), m_pDoc->unit()));
     xy.setY(KoUnit::toUserValue(xy.y(), m_pDoc->unit()));
-    TQString text = i18n("X: %1 %3 Y: %2 %4").arg(KGlobal::_locale->formatNumber(xy.x(), 2))
-      .arg(KGlobal::_locale->formatNumber(xy.y(), 2)).arg(unit).arg(unit);
+    TQString text = i18n("X: %1 %3 Y: %2 %4").arg(TDEGlobal::_locale->formatNumber(xy.x(), 2))
+      .arg(TDEGlobal::_locale->formatNumber(xy.y(), 2)).arg(unit).arg(unit);
     m_coordSLbl->setText(text);
   }
 }
