@@ -21,7 +21,7 @@
 
 #include <tqwidget.h>
 
-class KListView;
+class TDEListView;
 class KivioView;
 
 namespace Kivio {
@@ -32,7 +32,7 @@ namespace Kivio {
 class ObjectListPalette : public TQWidget
 {
   Q_OBJECT
-  TQ_OBJECT
+  
   public:
     ObjectListPalette(KivioView* parent = 0, const char* name = 0);
     ~ObjectListPalette();
@@ -44,7 +44,7 @@ class ObjectListPalette : public TQWidget
 
   private:
     KivioView* m_view;
-    KListView* m_objectList;
+    TDEListView* m_objectList;
 
     bool m_blockUpdate;
 };
