@@ -24,11 +24,11 @@
 
 #include <klibloader.h>
 
-class KInstance;
+class TDEInstance;
 
 class ConnectorToolFactory : public KLibFactory
 { Q_OBJECT
-  TQ_OBJECT
+  
 public:
   ConnectorToolFactory( TQObject* parent = 0, const char* name = 0 );
   ~ConnectorToolFactory();
@@ -36,10 +36,10 @@ public:
   virtual TQObject* createObject( TQObject* parent = 0, const char* name = 0,
                            const char* classname = TQOBJECT_OBJECT_NAME_STRING, const TQStringList &args = TQStringList() );
 
-  static KInstance* global();
+  static TDEInstance* global();
 
 private:
-  static KInstance* s_global;
+  static TDEInstance* s_global;
 };
 
 #endif
