@@ -23,10 +23,10 @@
 #endif
 
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <KoUnitWidgets.h>
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kdialogbase.h>
 #include <kiconloader.h>
 #include <knuminput.h>
@@ -64,19 +64,19 @@
 #include <tqlineedit.h>
 #include "KPrCommand.h"
 #include <tqvgroupbox.h>
-#include <kfontdialog.h>
+#include <tdefontdialog.h>
 #include <klineedit.h>
 #include <KoRect.h>
-#include <kmessagebox.h>
-#include <kdeversion.h>
+#include <tdemessagebox.h>
+#include <tdeversion.h>
 #include <kurlrequesterdlg.h>
-#include <klistview.h>
-#include <kfiledialog.h>
+#include <tdelistview.h>
+#include <tdefiledialog.h>
 #include <KoEditPath.h>
 
-#include <kspell2/configwidget.h>
-#include <kspell2/settings.h>
-#include <kspell2/broker.h>
+#include <tdespell2/configwidget.h>
+#include <tdespell2/settings.h>
+#include <tdespell2/broker.h>
 using namespace KSpell2;
 
 KPrConfig::KPrConfig( KPrView* parent )
@@ -87,27 +87,27 @@ KPrConfig::KPrConfig( KPrView* parent )
 {
     m_doc = parent->kPresenterDoc();
     TQVBox *page = addVBoxPage( i18n("Interface"), i18n("Interface"),
-                               BarIcon("misc", KIcon::SizeMedium) );
+                               BarIcon("misc", TDEIcon::SizeMedium) );
     _interfacePage=new KPrConfigureInterfacePage( parent, page );
     page = addVBoxPage( i18n("Color"), i18n("Color"),
-                        BarIcon("colorize", KIcon::SizeMedium) );
+                        BarIcon("colorize", TDEIcon::SizeMedium) );
     _colorBackground = new KPrConfigureColorBackground( parent, page );
 
     page = addVBoxPage( i18n("Spelling"), i18n("Spellchecker Behavior"),
-                        BarIcon("spellcheck", KIcon::SizeMedium) );
+                        BarIcon("tools-check-spelling", TDEIcon::SizeMedium) );
     _spellPage=new KPrConfigureSpellPage(parent, page);
 
     page = addVBoxPage( i18n("Misc"), i18n("Misc"),
-                        BarIcon("misc", KIcon::SizeMedium) );
+                        BarIcon("misc", TDEIcon::SizeMedium) );
     _miscPage=new KPrConfigureMiscPage(parent, page);
 
     page = addVBoxPage( i18n("Document"), i18n("Document Settings"),
-                        BarIcon("kpresenter_kpr", KIcon::SizeMedium) );
+                        BarIcon("application-x-kpresenter", TDEIcon::SizeMedium) );
 
     _defaultDocPage=new KPrConfigureDefaultDocPage(parent, page);
 
     page = addVBoxPage( i18n("Tools"), i18n("Default Tools Settings"),
-                        BarIcon("configure", KIcon::SizeMedium) );
+                        BarIcon("configure", TDEIcon::SizeMedium) );
 
     _toolsPage=new KPrConfigureToolsPage(parent, page);
 
@@ -118,7 +118,7 @@ KPrConfig::KPrConfig( KPrView* parent )
 
     if (KoSpeaker::isKttsdInstalled()) {
         page = addVBoxPage( i18n("Abbreviation for Text-to-Speech", "TTS"), i18n("Text-to-Speech Settings"),
-                            BarIcon("access", KIcon::SizeMedium) );
+                            BarIcon("access", TDEIcon::SizeMedium) );
         m_ttsPage=new KPrConfigureTTSPage(parent, page);
     } else m_ttsPage = 0;
 
@@ -131,7 +131,7 @@ void KPrConfig::openPage(int flags)
         showPage( 0 );
     else if(flags & KP_COLOR)
         showPage(1 );
-    else if(flags & KP_KSPELL)
+    else if(flags & KP_TDESPELL)
         showPage(2);
     else if(flags & KP_MISC)
         showPage(3 );
@@ -629,7 +629,7 @@ KPrConfigureDefaultDocPage::KPrConfigureDefaultDocPage(KPrView *_view, TQWidget
     fontName->setFrameStyle(TQFrame::StyledPanel | TQFrame::Sunken);
 
     TQPushButton *chooseButton = new TQPushButton(i18n("Choose..."), fontContainer);
-    TQWhatsThis::add(chooseButton, i18n( "Click here if you want to set a new font. The KDE default Select Font dialog will then be displayed." ) );
+    TQWhatsThis::add(chooseButton, i18n( "Click here if you want to set a new font. The TDE default Select Font dialog will then be displayed." ) );
     connect(chooseButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectNewDefaultFont()));
 
     fontLayout->addWidget(fontTitle, 0, 0);
@@ -792,14 +792,14 @@ void KPrConfigureDefaultDocPage::slotDefault()
     m_tabStopWidth->setValue( MM_TO_POINT(15));
     m_createBackupFile->setChecked( true );
     m_directInsertCursor->setChecked( false );
-    m_globalLanguage->setCurrentText( KoGlobal::languageFromTag( KGlobal::locale()->language() ) );
+    m_globalLanguage->setCurrentText( KoGlobal::languageFromTag( TDEGlobal::locale()->language() ) );
     m_autoHyphenation->setChecked( false );
 }
 
 void KPrConfigureDefaultDocPage::selectNewDefaultFont() {
     TQStringList list;
-    KFontChooser::getFontList(list, KFontChooser::SmoothScalableFonts);
-    KFontDialog dlg( this, "Font Selector", false, true, list, true );
+    TDEFontChooser::getFontList(list, TDEFontChooser::SmoothScalableFonts);
+    TDEFontDialog dlg( this, "Font Selector", false, true, list, true );
     dlg.setFont(*font);
     int result = dlg.exec();
     if (KDialog::Accepted == result) {
@@ -939,7 +939,7 @@ KPrConfigurePathPage::KPrConfigurePathPage( KPrView *_view, TQWidget *parent, ch
     KPrDocument* doc = m_pView->kPresenterDoc();
     config = KPrFactory::global()->config();
 
-    m_pPathView = new KListView( this );
+    m_pPathView = new TDEListView( this );
     m_pPathView->setResizeMode(TQListView::NoColumn);
     m_pPathView->addColumn( i18n( "Type" ) );
     m_pPathView->addColumn( i18n( "Path" ) );
@@ -955,7 +955,7 @@ KPrConfigurePathPage::KPrConfigurePathPage( KPrView *_view, TQWidget *parent, ch
     connect( m_pPathView, TQT_SIGNAL( selectionChanged ( TQListViewItem * )),
              this, TQT_SLOT( slotSelectionChanged(TQListViewItem * )));
     slotSelectionChanged(m_pPathView->currentItem());
-    TQWhatsThis::add(m_modifyPath, i18n( "When you click this button, a small dialog will appear and, if Default path is unchecked, you can either enter a path yourself or choose one using the standard KDE file dialog." ) );
+    TQWhatsThis::add(m_modifyPath, i18n( "When you click this button, a small dialog will appear and, if Default path is unchecked, you can either enter a path yourself or choose one using the standard TDE file dialog." ) );
     box->addWidget(m_modifyPath);
 
 }
@@ -994,7 +994,7 @@ void KPrConfigurePathPage::slotDefault()
 {
     TQListViewItem * item = m_pPathView->findItem(i18n("Picture Path"), 0);
     if ( item )
-        item->setText(1, KGlobalSettings::documentPath());
+        item->setText(1, TDEGlobalSettings::documentPath());
     item = m_pPathView->findItem(i18n("Backup Path"), 0);
     if ( item )
         item->setText(1, TQString() );
