@@ -59,10 +59,10 @@ class TQToolButton;
 class KPrSideBar;
 class KPrNoteBar;
 
-class KAction;
-class KActionMenu;
-class KToggleAction;
-class TKSelectColorAction;
+class TDEAction;
+class TDEActionMenu;
+class TDEToggleAction;
+class TTDESelectColorAction;
 class KoPartSelectAction;
 class KoPicture;
 class KoParagStyle;
@@ -77,12 +77,12 @@ class KoTextZoomHandler;
 
 class KCommand;
 class KMacroCommand;
-class KFontSizeAction;
+class TDEFontSizeAction;
 class KColorAction;
-class KSelectAction;
-class KFontAction;
+class TDESelectAction;
+class TDEFontAction;
 class KoParagCounter;
-class KActionMenu;
+class TDEActionMenu;
 class KoSearchContext;
 class KPrFindReplace;
 class KPrCanvas;
@@ -97,7 +97,7 @@ class KoTextIterator;
 class KStatusBarLabel;
 
 class KoSpell;
-#include <kspell2/broker.h>
+#include <tdespell2/broker.h>
 namespace KSpell2 {
     class Dialog;
 }
@@ -118,7 +118,7 @@ class KPrView : public KoView
 {
     friend class PageBase;
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     KPrView( KPrDocument* _doc, TQWidget *_parent = 0, const char *_name = 0 );
@@ -171,7 +171,7 @@ public:
     void insertFile(const TQString &path);
     void testAndCloseAllTextObjectProtectedContent();
     void updateRulerInProtectContentMode();
-    TQPtrList<KAction> listOfResultOfCheckWord( const TQString &word );
+    TQPtrList<TDEAction> listOfResultOfCheckWord( const TQString &word );
 
     /**
      * Returns the KPresenter global KSpell2 Broker object.
@@ -528,8 +528,8 @@ public:
     bool getGUnbalanced() const { return gUnbalanced; }
     int getGXFactor() const { return gXFactor; }
     int getGYFactor() const { return gYFactor; }
-    TKSelectColorAction* getActionBrushColor() const { return actionBrushColor; }
-    TKSelectColorAction* getActionPenColor() const { return actionPenColor; }
+    TTDESelectColorAction* getActionBrushColor() const { return actionBrushColor; }
+    TTDESelectColorAction* getActionPenColor() const { return actionPenColor; }
 
     void setPieType(PieType _pieType) { pieType = _pieType; }
     void setPieAngle(int _pieAngle) { pieAngle = _pieAngle; }
@@ -632,9 +632,9 @@ public:
     KPrNoteBar *getNoteBar() const { return notebar; }
 
     // Used by Page to plug/unplug the datatool actions
-    TQPtrList<KAction>& actionList() { return m_actionList; }
+    TQPtrList<TDEAction>& actionList() { return m_actionList; }
     // Used by Page to plug/unplug the variable actions
-    TQPtrList<KAction> &variableActionList() { return m_variableActionList; }
+    TQPtrList<TDEAction> &variableActionList() { return m_variableActionList; }
 
     // for Polygon object
     bool getCheckConcavePolygon() const { return checkConcavePolygon; }
@@ -781,7 +781,7 @@ protected:
     virtual void updateReadWrite( bool readwrite );
 
     void addVariableActions( int type, const TQStringList & texts,
-                             KActionMenu * parentMenu, const TQString & menuText );
+                             TDEActionMenu * parentMenu, const TQString & menuText );
 
     void showParagraphDialog( int initialPage = -1, double initialTabPos = 0.0 );
 
@@ -832,8 +832,8 @@ private:
     // right button popup menus
     TQPopupMenu *rb_lbegin, *rb_lend;
     TQPopupMenu *m_arrangeObjectsPopup;
-    TQPtrList<KAction> m_actionList; // for the kodatatools
-    TQPtrList<KAction> m_variableActionList;
+    TQPtrList<TDEAction> m_actionList; // for the kodatatools
+    TQPtrList<TDEAction> m_variableActionList;
 
     // scrollbars
     TQScrollBar *vert, *horz;
@@ -906,160 +906,160 @@ private:
     KStatusBarLabel* m_sbZoomLabel;
 
     // actions
-    KAction *actionEditCut;
-    KAction *actionEditCustomVars;
-    KAction *actionEditCopy;
-    KAction *actionEditPaste;
-    KAction *actionEditDelete;
-    KAction *actionEditSelectAll;
-    KAction *actionEditDeSelectAll;
-    KAction *actionEditCopyPage;
-    KAction *actionEditDuplicatePage;
-    KAction *actionEditDelPage;
+    TDEAction *actionEditCut;
+    TDEAction *actionEditCustomVars;
+    TDEAction *actionEditCopy;
+    TDEAction *actionEditPaste;
+    TDEAction *actionEditDelete;
+    TDEAction *actionEditSelectAll;
+    TDEAction *actionEditDeSelectAll;
+    TDEAction *actionEditCopyPage;
+    TDEAction *actionEditDuplicatePage;
+    TDEAction *actionEditDelPage;
 
-    KToggleAction *actionViewShowSideBar;
-    KToggleAction *actionViewShowNoteBar;
-    KToggleAction *actionViewSlideMaster;
+    TDEToggleAction *actionViewShowSideBar;
+    TDEToggleAction *actionViewShowNoteBar;
+    TDEToggleAction *actionViewSlideMaster;
 
-    KToggleAction *actionViewShowGuideLine;
+    TDEToggleAction *actionViewShowGuideLine;
 
-    KToggleAction *actionViewFormattingChars;
-    KToggleAction *actionViewShowGrid;
-    KToggleAction *actionViewSnapToGrid;
+    TDEToggleAction *actionViewFormattingChars;
+    TDEToggleAction *actionViewShowGrid;
+    TDEToggleAction *actionViewSnapToGrid;
 
-    KAction *actionInsertPage;
-    KAction *actionInsertPicture;
+    TDEAction *actionInsertPage;
+    TDEAction *actionInsertPicture;
 
-    KToggleAction *actionToolsMouse;
-    KToggleAction *actionToolsRotate;
-    KToggleAction *actionToolsZoom;
-    KToggleAction *actionToolsLine;
-    KToggleAction *actionToolsRectangle;
-    KToggleAction *actionToolsCircleOrEllipse;
-    KToggleAction *actionToolsPie;
-    KToggleAction *actionToolsText;
-    KToggleAction *actionToolsAutoform;
-    KToggleAction *actionToolsDiagramm;
-    KToggleAction *actionToolsTable;
-    KToggleAction *actionToolsFormula;
-    KToggleAction *actionToolsFreehand;
-    KToggleAction *actionToolsPolyline;
-    KToggleAction *actionToolsQuadricBezierCurve;
-    KToggleAction *actionToolsCubicBezierCurve;
-    KToggleAction *actionToolsConvexOrConcavePolygon;
-    KToggleAction *actionToolsClosedFreehand;
-    KToggleAction *actionToolsClosedPolyline;
-    KToggleAction *actionToolsClosedQuadricBezierCurve;
-    KToggleAction *actionToolsClosedCubicBezierCurve;
+    TDEToggleAction *actionToolsMouse;
+    TDEToggleAction *actionToolsRotate;
+    TDEToggleAction *actionToolsZoom;
+    TDEToggleAction *actionToolsLine;
+    TDEToggleAction *actionToolsRectangle;
+    TDEToggleAction *actionToolsCircleOrEllipse;
+    TDEToggleAction *actionToolsPie;
+    TDEToggleAction *actionToolsText;
+    TDEToggleAction *actionToolsAutoform;
+    TDEToggleAction *actionToolsDiagramm;
+    TDEToggleAction *actionToolsTable;
+    TDEToggleAction *actionToolsFormula;
+    TDEToggleAction *actionToolsFreehand;
+    TDEToggleAction *actionToolsPolyline;
+    TDEToggleAction *actionToolsQuadricBezierCurve;
+    TDEToggleAction *actionToolsCubicBezierCurve;
+    TDEToggleAction *actionToolsConvexOrConcavePolygon;
+    TDEToggleAction *actionToolsClosedFreehand;
+    TDEToggleAction *actionToolsClosedPolyline;
+    TDEToggleAction *actionToolsClosedQuadricBezierCurve;
+    TDEToggleAction *actionToolsClosedCubicBezierCurve;
     KoPartSelectAction *actionToolsObject;
-    KActionMenu *actionToolsLinePopup;
-    KActionMenu *actionToolsShapePopup;
-    KActionMenu *actionToolsClosedLinePopup;
+    TDEActionMenu *actionToolsLinePopup;
+    TDEActionMenu *actionToolsShapePopup;
+    TDEActionMenu *actionToolsClosedLinePopup;
 
-    KAction *actionTextFont;
-    KFontSizeAction *actionTextFontSize;
-    KFontAction *actionTextFontFamily;
-    KToggleAction *actionTextAlignLeft;
-    KToggleAction *actionTextAlignCenter;
-    KToggleAction *actionTextAlignRight;
-    KToggleAction *actionTextAlignBlock;
+    TDEAction *actionTextFont;
+    TDEFontSizeAction *actionTextFontSize;
+    TDEFontAction *actionTextFontFamily;
+    TDEToggleAction *actionTextAlignLeft;
+    TDEToggleAction *actionTextAlignCenter;
+    TDEToggleAction *actionTextAlignRight;
+    TDEToggleAction *actionTextAlignBlock;
 
-    KActionMenu *actionFormatBullet;
-    KActionMenu *actionFormatNumber;
+    TDEActionMenu *actionFormatBullet;
+    TDEActionMenu *actionFormatNumber;
 
 
-    KAction *actionTextDepthPlus;
-    KAction *actionTextDepthMinus;
-    KAction *actionTextExtentCont2Height;
-    KAction *actionTextExtendObj2Cont;
-    KToggleAction *actionTextBold;
-    KToggleAction *actionTextItalic;
-    KToggleAction *actionTextUnderline;
-    KToggleAction *actionFormatStrikeOut;
-    KAction *actionTextInsertPageNum;
+    TDEAction *actionTextDepthPlus;
+    TDEAction *actionTextDepthMinus;
+    TDEAction *actionTextExtentCont2Height;
+    TDEAction *actionTextExtendObj2Cont;
+    TDEToggleAction *actionTextBold;
+    TDEToggleAction *actionTextItalic;
+    TDEToggleAction *actionTextUnderline;
+    TDEToggleAction *actionFormatStrikeOut;
+    TDEAction *actionTextInsertPageNum;
 
-    KAction *actionExtraProperties;
-    KAction *actionExtraRaise;
-    KAction *actionExtraLower;
+    TDEAction *actionExtraProperties;
+    TDEAction *actionExtraRaise;
+    TDEAction *actionExtraLower;
 
-    KAction *actionExtraBringForward;
-    KAction *actionExtraSendBackward;
-    KActionMenu *actionExtraArrangePopup;
+    TDEAction *actionExtraBringForward;
+    TDEAction *actionExtraSendBackward;
+    TDEActionMenu *actionExtraArrangePopup;
 
-    KAction *actionExtraRotate;
-    KAction *actionExtraShadow;
-    KActionMenu *actionExtraAlignObjsPopup;
-    KAction *actionExtraAlignObjLeft;
-    KAction *actionExtraAlignObjCenterH;
-    KAction *actionExtraAlignObjRight;
-    KAction *actionExtraAlignObjTop;
-    KAction *actionExtraAlignObjCenterV;
-    KAction *actionExtraAlignObjBottom;
-    KAction *actionExtraBackground;
-    KAction *actionExtraLayout;
-    KAction *actionExtraConfigure;
-    KAction *actionExtraWebPres;
-    KAction *actionExtraMSPres;
-    KAction *actionExtraCreateTemplate;
-    KAction *actionExtraLineBegin;
-    KAction *actionExtraLineEnd;
-    KAction *actionExtraGroup;
-    KAction *actionExtraUnGroup;
+    TDEAction *actionExtraRotate;
+    TDEAction *actionExtraShadow;
+    TDEActionMenu *actionExtraAlignObjsPopup;
+    TDEAction *actionExtraAlignObjLeft;
+    TDEAction *actionExtraAlignObjCenterH;
+    TDEAction *actionExtraAlignObjRight;
+    TDEAction *actionExtraAlignObjTop;
+    TDEAction *actionExtraAlignObjCenterV;
+    TDEAction *actionExtraAlignObjBottom;
+    TDEAction *actionExtraBackground;
+    TDEAction *actionExtraLayout;
+    TDEAction *actionExtraConfigure;
+    TDEAction *actionExtraWebPres;
+    TDEAction *actionExtraMSPres;
+    TDEAction *actionExtraCreateTemplate;
+    TDEAction *actionExtraLineBegin;
+    TDEAction *actionExtraLineEnd;
+    TDEAction *actionExtraGroup;
+    TDEAction *actionExtraUnGroup;
     KoLineStyleAction *actionExtraPenStyle;
     KoLineWidthAction *actionExtraPenWidth;
 
-    KAction *actionScreenConfigPages;
-    KAction *actionScreenAssignEffect;
-    KAction *actionScreenTransEffect;
-    KAction *actionScreenStart;
-    KAction *actionScreenStartFromFirst;
-    KAction *actionScreenStop;
-    KAction *actionScreenPause;
-    KAction *actionScreenFirst;
-    KAction *actionScreenPrev;
-    KAction *actionScreenNext;
-    KAction *actionScreenLast;
-    KAction *actionScreenSkip;
+    TDEAction *actionScreenConfigPages;
+    TDEAction *actionScreenAssignEffect;
+    TDEAction *actionScreenTransEffect;
+    TDEAction *actionScreenStart;
+    TDEAction *actionScreenStartFromFirst;
+    TDEAction *actionScreenStop;
+    TDEAction *actionScreenPause;
+    TDEAction *actionScreenFirst;
+    TDEAction *actionScreenPrev;
+    TDEAction *actionScreenNext;
+    TDEAction *actionScreenLast;
+    TDEAction *actionScreenSkip;
 
-    KAction *actionEditFind;
-    KAction *actionEditFindNext;
-    KAction *actionEditFindPrevious;
-    KAction *actionEditReplace;
+    TDEAction *actionEditFind;
+    TDEAction *actionEditFindNext;
+    TDEAction *actionEditFindPrevious;
+    TDEAction *actionEditReplace;
 
-    KAction *actionCustomSlideShow;
+    TDEAction *actionCustomSlideShow;
 
-    KAction *actionColorBar;
-    KAction *actionExtraDefaultTemplate;
+    TDEAction *actionColorBar;
+    TDEAction *actionExtraDefaultTemplate;
 
-    TKSelectColorAction* actionBrushColor;
-    TKSelectColorAction* actionPenColor;
-    TKSelectColorAction* actionTextColor;
+    TTDESelectColorAction* actionBrushColor;
+    TTDESelectColorAction* actionPenColor;
+    TTDESelectColorAction* actionTextColor;
 
 
-    KAction *actionResizeTextObject;
-    KAction *actionExtendObjectHeight;
-    KAction *actionObjectProperties;
+    TDEAction *actionResizeTextObject;
+    TDEAction *actionExtendObjectHeight;
+    TDEAction *actionObjectProperties;
 
-    KAction *actionRenamePage;
+    TDEAction *actionRenamePage;
 
-    KAction *actionPicOriginalSize;
-    KAction *actionPic640x480;
-    KAction *actionPic800x600;
-    KAction *actionPic1024x768;
-    KAction *actionPic1280x1024;
-    KAction *actionPic1600x1200;
-    KAction *actionChangePic;
-    KAction *actionExtraSpellCheck;
-    KAction *actionFormatDefault;
+    TDEAction *actionPicOriginalSize;
+    TDEAction *actionPic640x480;
+    TDEAction *actionPic800x600;
+    TDEAction *actionPic1024x768;
+    TDEAction *actionPic1280x1024;
+    TDEAction *actionPic1600x1200;
+    TDEAction *actionChangePic;
+    TDEAction *actionExtraSpellCheck;
+    TDEAction *actionFormatDefault;
 
-    KAction *actionImageEffect;
+    TDEAction *actionImageEffect;
 
-    KAction *actionInsertComment;
-    KAction *actionEditComment;
-    KAction *actionRemoveComment;
-    KAction *actionCopyTextOfComment;
+    TDEAction *actionInsertComment;
+    TDEAction *actionEditComment;
+    TDEAction *actionRemoveComment;
+    TDEAction *actionCopyTextOfComment;
 
-    KAction *actionImportStyle;
+    TDEAction *actionImportStyle;
 
     DCOPObject *dcop;
 
@@ -1069,79 +1069,79 @@ private:
     TQSplitter *splitter;
     PageBase *pageBase;
 
-    KToggleAction *actionFormatSuper;
-    KToggleAction *actionFormatSub;
+    TDEToggleAction *actionFormatSuper;
+    TDEToggleAction *actionFormatSub;
 
-    KToggleAction *m_actionExtraHeader;
-    KToggleAction *m_actionExtraFooter;
+    TDEToggleAction *m_actionExtraHeader;
+    TDEToggleAction *m_actionExtraFooter;
 
-    KAction* actionInsertSpecialChar;
-    KAction *actionInsertLink;
+    TDEAction* actionInsertSpecialChar;
+    TDEAction *actionInsertLink;
 
-    KAction * actionChangeLink;
-    KAction *actionCopyLink;
-    KAction *actionRemoveLink;
+    TDEAction * actionChangeLink;
+    TDEAction *actionCopyLink;
+    TDEAction *actionRemoveLink;
 
-    KAction *actionAddLinkToBookmak;
-    KAction *actionFormatParag;
-    KAction *actionOpenLink;
-    KAction *actionIncreaseFontSize;
-    KAction *actionDecreaseFontSize;
-    KAction *actionChangeCase;
-    KAction *actionRefreshAllVariable;
+    TDEAction *actionAddLinkToBookmak;
+    TDEAction *actionFormatParag;
+    TDEAction *actionOpenLink;
+    TDEAction *actionIncreaseFontSize;
+    TDEAction *actionDecreaseFontSize;
+    TDEAction *actionChangeCase;
+    TDEAction *actionRefreshAllVariable;
 
-    KSelectAction *actionViewZoom;
+    TDESelectAction *actionViewZoom;
 
-    KSelectAction *actionFormatStyle;
+    TDESelectAction *actionFormatStyle;
 
-    KToggleAction *actionAllowAutoFormat;
+    TDEToggleAction *actionAllowAutoFormat;
 
-    KToggleAction *actionDisplayObjectFromMasterPage;
+    TDEToggleAction *actionDisplayObjectFromMasterPage;
 
-    KToggleAction *actionDisplayBackgroundPage;
+    TDEToggleAction *actionDisplayBackgroundPage;
 
-    KAction *actionFormatStylist;
+    TDEAction *actionFormatStylist;
 
-    KAction *actionAddGuideLine;
+    TDEAction *actionAddGuideLine;
 
-    KAction *actionConfigureCompletion;
+    TDEAction *actionConfigureCompletion;
 
-    KAction *actionZoomMinus;
-    KAction *actionZoomPageWidth;
-    KAction *actionZoomEntirePage;
-    KAction *actionZoomPlus;
-    KAction *actionZoomSelectedObject;
-    KAction *actionZoomPageHeight;
-    KAction *actionZoomAllObject;
+    TDEAction *actionZoomMinus;
+    TDEAction *actionZoomPageWidth;
+    TDEAction *actionZoomEntirePage;
+    TDEAction *actionZoomPlus;
+    TDEAction *actionZoomSelectedObject;
+    TDEAction *actionZoomPageHeight;
+    TDEAction *actionZoomAllObject;
 
-    KAction *actionFlipHorizontal;
-    KAction *actionFlipVertical;
-    KAction *actionCloseObject;
+    TDEAction *actionFlipHorizontal;
+    TDEAction *actionFlipVertical;
+    TDEAction *actionCloseObject;
 
-    KAction *actionDuplicateObj;
-    KAction *actionApplyAutoFormat;
+    TDEAction *actionDuplicateObj;
+    TDEAction *actionApplyAutoFormat;
 
-    KAction *actionCreateStyleFromSelection;
+    TDEAction *actionCreateStyleFromSelection;
 
-    KAction *actionSavePicture;
+    TDEAction *actionSavePicture;
 
-    KAction *actionSaveBackgroundPicture;
+    TDEAction *actionSaveBackgroundPicture;
 
 
-    KAction *actionInsertFile;
+    TDEAction *actionInsertFile;
 
-    KAction *actionSpellIgnoreAll;
+    TDEAction *actionSpellIgnoreAll;
 
-    KToggleAction *actionAlignVerticalTop;
-    KToggleAction *actionAlignVerticalBottom;
-    KToggleAction *actionAlignVerticalCenter;
+    TDEToggleAction *actionAlignVerticalTop;
+    TDEToggleAction *actionAlignVerticalBottom;
+    TDEToggleAction *actionAlignVerticalCenter;
 
-    KToggleAction *actionAllowBgSpellCheck;
-    KAction *actionEditCustomVarsEdit;
-    KActionMenu *actionFormatStyleMenu;
-    KToggleAction *actionInsertDirectCursor;
+    TDEToggleAction *actionAllowBgSpellCheck;
+    TDEAction *actionEditCustomVarsEdit;
+    TDEActionMenu *actionFormatStyleMenu;
+    TDEToggleAction *actionInsertDirectCursor;
 
-    KAction *actionAddWordToPersonalDictionary;
+    TDEAction *actionAddWordToPersonalDictionary;
 
     /// timer for automatic presentation mode
     TQTimer m_autoPresTimer;
@@ -1205,14 +1205,14 @@ private:
 
 
 
-    KActionMenu *actionInsertVariable;
-    KActionMenu *actionInsertCustom;
+    TDEActionMenu *actionInsertVariable;
+    TDEActionMenu *actionInsertCustom;
 
     struct VariableDef {
         int type;
         int subtype;
     };
-    typedef TQMap<KAction *, VariableDef> VariableDefMap;
+    typedef TQMap<TDEAction *, VariableDef> VariableDefMap;
     VariableDefMap m_variableDefMap;
 
     KoSearchContext *m_searchEntry, *m_replaceEntry;
