@@ -34,7 +34,7 @@
 #include <tqvaluelist.h>
 
 #include <kprinter.h>
-#include <kdeprint/kprintdialogpage.h>
+#include <tdeprint/kprintdialogpage.h>
 
 #include <KoPoint.h>
 #include <KoView.h>
@@ -80,7 +80,7 @@ class EmbeddedObject;
 class KPSheetSelectPage : public KPrintDialogPage
 {
   Q_OBJECT
-  TQ_OBJECT
+  
   public:
     KPSheetSelectPage( TQWidget *parent = 0 );
 //     ~KPSheetSelectPage();
@@ -189,7 +189,7 @@ class KSPREAD_EXPORT View : public KoView
     friend class Canvas;
 
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
 
     /** Creates a new view */
