@@ -22,7 +22,7 @@
 #ifndef SCRIPTING_H
 #define SCRIPTING_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 #include <kspread_view.h>
 
 namespace Kross {
@@ -35,7 +35,7 @@ namespace Kross {
 class Scripting : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     public:
         Scripting(TQObject *parent, const char *name, const TQStringList &);
         virtual ~Scripting();
