@@ -651,13 +651,13 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt, kdecore, dcop, dcopext',
-					'dcopclient = kdecore.KApplication.dcopClient()',
+					'import qt, tdecore, dcop, dcopext',
+					'dcopclient = tdecore.TDEApplication.dcopClient()',
 					'apps = [ app for app in dcopclient.registeredApplications() if str(app).startswith("klipper") ]',
 					'd = dcopext.DCOPApp(apps[0], dcopclient)',
 					'result,typename,data = d.appclient.call(apps[0],"klipper","getClipboardContents()","")',
 					'ds = qt.QDataStream(data, qt.IO_ReadOnly)',
-					'print "Clipboard content:\\n%s" % kdecore.dcop_next(ds, TQSTRING_OBJECT_NAME_STRING)',
+					'print "Clipboard content:\\n%s" % tdecore.dcop_next(ds, TQSTRING_OBJECT_NAME_STRING)',
 				)
 
 		class AmarokCollectionInfos:
@@ -668,17 +668,17 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt, kdecore, dcop, dcopext',
+					'import qt, tdecore, dcop, dcopext',
 					'',
-					'dcopclient = kdecore.KApplication.dcopClient()',
+					'dcopclient = tdecore.TDEApplication.dcopClient()',
 					'apps = [ app for app in dcopclient.registeredApplications() if str(app).startswith("amarok") ]',
 					'app = apps[0]',
 					'd = dcopext.DCOPApp(app, dcopclient)',
 					'',
 					'def dataToList(data, types = []):',
-					'	import qt, kdecore',
+					'	import qt, tdecore',
 					'	ds = qt.QDataStream(data, qt.IO_ReadOnly)',
-					'	return [ kdecore.dcop_next(ds, t) for t in types ]',
+					'	return [ tdecore.dcop_next(ds, t) for t in types ]',
 					'',
 					'for funcname in ["totalAlbums","totalArtists","totalCompilations","totalGenres","totalTracks"]:',
 					'	result,replytype,replydata = d.appclient.call("amarok", "collection", "%s()" % funcname,"")',
@@ -693,9 +693,9 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt, kdecore, dcop, dcopext',
+					'import qt, tdecore, dcop, dcopext',
 					'',
-					'dcopclient = kdecore.KApplication.dcopClient()',
+					'dcopclient = tdecore.TDEApplication.dcopClient()',
 					'apps = [ app for app in dcopclient.registeredApplications() if str(app).startswith("kopete") ]',
 					'app = apps[0]',
 					'd = dcopext.DCOPApp(app, dcopclient)',
@@ -704,7 +704,7 @@ class Samples:
 					'if not state: raise "Failed to call the kopete contacts-function"',
 					'',
 					'ds = qt.QDataStream(rdata.data(), qt.IO_ReadOnly)',
-					'sl = kdecore.dcop_next (ds, TQSTRINGLIST_OBJECT_NAME_STRING)',
+					'sl = tdecore.dcop_next (ds, TQSTRINGLIST_OBJECT_NAME_STRING)',
 					'print "contacts=%s" % [ str(s) for s in sl ]',
 				)
 
@@ -716,22 +716,22 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt, kdecore, dcop, dcopext',
+					'import qt, tdecore, dcop, dcopext',
 					'',
 					'def dataToList(data, types = []):',
-					'	import qt, kdecore',
+					'	import qt, tdecore',
 					'	ds = qt.QDataStream(data, qt.IO_ReadOnly)',
-					'	return [ kdecore.dcop_next(ds, t) for t in types ]',
+					'	return [ tdecore.dcop_next(ds, t) for t in types ]',
 					'def listToData(listdict):',
-					'	import qt, kdecore',
+					'	import qt, tdecore',
 					'	ba= qt.QByteArray()',
 					'	ds = qt.QDataStream(ba, qt.IO_WriteOnly)',
 					'	for (typename,value) in listdict:',
-					'		kdecore.dcop_add (ds, value, typename)',
+					'		tdecore.dcop_add (ds, value, typename)',
 					'	return ba',
 					'',
 					'# Get the KWord DCOP client.',
-					'dcopclient = kdecore.KApplication.dcopClient()',
+					'dcopclient = tdecore.TDEApplication.dcopClient()',
 					'apps = [ app for app in dcopclient.registeredApplications() if str(app).startswith("kword") ]',
 					'if len(apps) < 1: raise "No KWord instance is running. Please start KWord before!"',
 					'appname = apps[0]',
