@@ -78,7 +78,7 @@ void SelectionRect::draw( TQPainter & painter )
             mp.convertFromImage(im,  TQt::OrderedAlphaDither);
 
             kdDebug(31000) << "creating brush" << endl;
-            TQBrush br(KGlobalSettings::highlightColor(),TQt::CustomPattern);
+            TQBrush br(TDEGlobalSettings::highlightColor(),TQt::CustomPattern);
             br.setPixmap(mp);
             painter.setBrush(br);
         }
@@ -154,7 +154,7 @@ void View::selectItemFromList( TQCanvasItemList &l )
                 m_canvas->unselectAll();
                 m_canvas->selectItem( b, false );
                 m_canvas->update();
-                //                qWarning("selected item set");
+                //                tqWarning("selected item set");
                 //                selected->drawHolders();
                 return ;
             }
@@ -171,7 +171,7 @@ void View::selectItemFromList( TQCanvasItemList &l )
         }
     }
     m_canvas->unselectAll();
-    //    qWarning("unselect");
+    //    tqWarning("unselect");
 }
 
 
@@ -206,8 +206,8 @@ bool View::startResizing( TQMouseEvent * /*e*/, TQPoint &p )
     {
         Kudesigner::Box *cbx = *it;
         resizing_type = cbx->isInHolder( p );
-        /*        qWarning("POINT: %d %d", p.x(), p.y());
-                qWarning("RESIZE: %d", resizing_type);*/
+        /*        tqWarning("POINT: %d %d", p.x(), p.y());
+                tqWarning("RESIZE: %d", resizing_type);*/
         if ( resizing_type )
         {
             m_canvas->selectItem( cbx, false );
@@ -280,14 +280,14 @@ void View::startMoveOrResizeOrSelectItem( TQCanvasItemList &l,
     }
     moving = 0;
     resizing = 0;
-    //         qWarning("1");
+    //         tqWarning("1");
     selectionStarted = 1;
     selectionRect->setX( p.x() );
     selectionRect->setY( p.y() );
     selectionRect->setZ( 50 );
-    //         qWarning("2");
+    //         tqWarning("2");
     selectionRect->show();
-    //         qWarning("3");
+    //         tqWarning("3");
 }
 
 void View::contentsMousePressEvent( TQMouseEvent* e )
@@ -298,7 +298,7 @@ void View::contentsMousePressEvent( TQMouseEvent* e )
     //if there is a request for properties or for delete operation
     //perform that and do not take care about mouse buttons
 
-    //    qWarning("mouse press");
+    //    tqWarning("mouse press");
 
     switch ( request )
     {
@@ -321,9 +321,9 @@ void View::contentsMousePressEvent( TQMouseEvent* e )
 
 
     /*    Kudesigner::Box *b;
-        qWarning("Selected items:");
+        tqWarning("Selected items:");
         for (b = selected.first(); b; b = selected.next())
-            qWarning("%s", b->props["Text"].first.latin1());
+            tqWarning("%s", b->props["Text"].first.latin1());
 
       */
     switch ( e->button() )
@@ -331,13 +331,13 @@ void View::contentsMousePressEvent( TQMouseEvent* e )
     case Qt::LeftButton:
         if ( itemToInsert )
         {
-            //                qWarning("placing item");
+            //                tqWarning("placing item");
             m_canvas->unselectAll();
             placeItem( l, e );
         }
         else
         {
-            //                qWarning("starting move or resize");
+            //                tqWarning("starting move or resize");
             if ( !startResizing( e, p ) )
             {
                 selectItemFromList( l );
@@ -696,9 +696,9 @@ void View::finishSelection()
         Kudesigner::Box *b = *it;
         Buffer *buf = new Buffer( &( b->props ) );
         ++it;
-        //         qWarning("== %d", m_canvas->selected.count());
+        //         tqWarning("== %d", m_canvas->selected.count());
         //         Kudesigner::BoxList::const_iterator it2 = m_canvas->selected.end();
-        //         qWarning("41: %d", it != it2);
+        //         tqWarning("41: %d", it != it2);
         for ( ; it != m_canvas->selected.end(); ++it )
         {
             b = *it;
