@@ -50,15 +50,15 @@
 #include <KoStoreDrag.h>
 #include <KoPictureCollection.h>
 
-#include <ktempfile.h>
-#include <klocale.h>
+#include <tdetempfile.h>
+#include <tdelocale.h>
 #include <kcursor.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
-#include <kmultipledrag.h>
+#include <tdemessagebox.h>
+#include <tdemultipledrag.h>
 #include <kurl.h>
 #include <kurldrag.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kmimetype.h>
 
 #include <assert.h>
@@ -216,7 +216,7 @@ void KWCanvas::print( TQPainter *painter, KPrinter *printer )
         m_currentFrameSetEdit->focusOutEvent();
     m_printing = true;
     KWViewMode *viewMode = new KWViewModePrint( m_doc, this );
-    // Use page list specified in kdeprint dialogbox
+    // Use page list specified in tdeprint dialogbox
     TQValueList<int> pageList = printer->pageList();
     TQProgressDialog progress( i18n( "Printing..." ), i18n( "Cancel" ),
                               pageList.count() + 1, this );
@@ -1516,7 +1516,7 @@ void KWCanvas::contentsDropEvent( TQDropEvent *e )
     } else if ( KURLDrag::canDecode( e ) ) {
 
         // TODO ask (with a popupmenu) between inserting a link and inserting the contents
-        // TODO fix khtml to export images when dragging an image+link (as it does when using "Copy")
+        // TODO fix tdehtml to export images when dragging an image+link (as it does when using "Copy")
 
         KURL::List lst;
         KURLDrag::decode( e, lst );
@@ -1526,7 +1526,7 @@ void KWCanvas::contentsDropEvent( TQDropEvent *e )
             const KURL &url( *it );
 
             TQString filename;
-            if ( !KIO::NetAccess::download( url, filename, this ) )
+            if ( !TDEIO::NetAccess::download( url, filename, this ) )
                 continue;
 
             KMimeType::Ptr res = KMimeType::findByFileContent( filename );
@@ -1542,7 +1542,7 @@ void KWCanvas::contentsDropEvent( TQDropEvent *e )
                     insertPictureDirect( newKoPicture, docPoint );
                 }
             }
-            KIO::NetAccess::removeTempFile( filename );
+            TDEIO::NetAccess::removeTempFile( filename );
         }
     }
     else
@@ -1590,7 +1590,7 @@ void KWCanvas::doAutoScroll()
         return;
     }
 
-    // This code comes from khtml
+    // This code comes from tdehtml
     TQPoint pos( mapFromGlobal( TQCursor::pos() ) );
 
     pos = TQPoint(pos.x() - viewport()->x(), pos.y() - viewport()->y());
@@ -1721,7 +1721,7 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
                     m_scrollTimer->stop();
                 m_mousePressed = false;
                 break;
-            case TQEvent::AccelOverride: // was part of KeyPress - changed due to kdelibs BUG!
+            case TQEvent::AccelOverride: // was part of KeyPress - changed due to tdelibs BUG!
             {
                 //  kdDebug() << " KeyPress m_currentFrameSetEdit=" << m_currentFrameSetEdit << " isRW="<<m_doc->isReadWrite() << endl;
                 //  kdDebug() << " m_printing=" << m_printing << " mousemode=" << m_mouseMode << " (MM_EDIT=" << MM_EDIT<<")"<<endl;
@@ -1779,7 +1779,7 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
                 // out of document window.  Disabled because it conflicts with Shift+Tab inside a table.
                 // else if ( keyev->key() == TQt::Key_BackTab )
                 //    return FALSE;
-                else if ( keyev->key() == KGlobalSettings::contextMenuKey() ) {
+                else if ( keyev->key() == TDEGlobalSettings::contextMenuKey() ) {
                     // The popups are not available in readonly mode, since the GUI isn't built...
                     if(!m_doc->isReadWrite()) return TRUE;
                     if (m_mouseMode != MM_EDIT) return TRUE;
