@@ -45,7 +45,7 @@ class KoTextObject;
 class KoDataToolInfo;
 class KoVariable;
 
-class KAction;
+class TDEAction;
 class KNamedCommand;
 class KMacroCommand;
 
@@ -63,7 +63,7 @@ class TQProgressDialog;
 class KWTextFrameSet : public KWFrameSet, public KoTextFlow, public KoTextFormatInterface
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     /// Cnstructor
     KWTextFrameSet( KWDocument *_doc, const TQString & name );
@@ -385,7 +385,7 @@ private:
 class KWTextFrameSetEdit : public KoTextView, public KWFrameSetEdit
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     KWTextFrameSetEdit( KWTextFrameSet * fs, KWCanvas * canvas );
     virtual ~KWTextFrameSetEdit();
