@@ -31,8 +31,8 @@
 #include <KoXmlNS.h>
 #include <KoOasisStyles.h>
 
-#include <kglobalsettings.h>
-#include <klocale.h>
+#include <tdeglobalsettings.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <assert.h>
 
@@ -70,7 +70,7 @@ void KWTextParag::drawFormattingChars( TQPainter &painter, int start, int len,
     if ( start + len == length() && (whichFormattingChars & FormattingBreak) && hardFrameBreakAfter() )
     {
         painter.save();
-        TQPen pen( KGlobalSettings::linkColor() ); // #101820
+        TQPen pen( TDEGlobalSettings::linkColor() ); // #101820
         painter.setPen( pen );
         //kdDebug() << "KWTextParag::drawFormattingChars start=" << start << " len=" << len << " length=" << length() << endl;
             // keep in sync with KWTextFrameSet::formatVertically
