@@ -34,7 +34,7 @@
 #include <KoPageLayoutDia.h>
 #include <KoView.h>
 #include <KoPoint.h>
-#include <kshortcut.h>
+#include <tdeshortcut.h>
 #include <KoZoomMode.h>
 
 #include <tqbrush.h>
@@ -61,7 +61,7 @@ class KoPicture;
 class KoSearchContext;
 class KoTextFormatInterface;
 class KoRuler;
-class TKSelectColorAction;
+class TTDESelectColorAction;
 class KoPartSelectAction;
 class KoCharSelectDia;
 class KoTextFormat;
@@ -73,16 +73,16 @@ class DCOPObject;
 class KStatusBarLabel;
 class KoSpell;
 class KURL;
-class KAction;
-class KActionMenu;
-class KSelectAction;
-class KToggleAction;
-class KFontSizeAction;
-class KFontAction;
+class TDEAction;
+class TDEActionMenu;
+class TDESelectAction;
+class TDEToggleAction;
+class TDEFontSizeAction;
+class TDEFontAction;
 class TQResizeEvent;
 class TQSplitter;
 
-#include <kspell2/broker.h>
+#include <tdespell2/broker.h>
 namespace KSpell2 {
     class Dialog;
 }
@@ -95,7 +95,7 @@ namespace KSpell2 {
 class KWView : public KoView
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     KWView( const TQString& viewMode, TQWidget *parent, const char *name, KWDocument *doc );
@@ -187,9 +187,9 @@ public:
 
     TQPopupMenu * popupMenu( const TQString& name );
 
-    TQPtrList<KAction> &dataToolActionList() { return m_actionList; }
-    TQPtrList<KAction> &variableActionList() { return m_variableActionList; }
-    TQPtrList<KAction> &tableActions() { return m_tableActionList; }
+    TQPtrList<TDEAction> &dataToolActionList() { return m_actionList; }
+    TQPtrList<TDEAction> &variableActionList() { return m_variableActionList; }
+    TQPtrList<TDEAction> &tableActions() { return m_tableActionList; }
 
     enum { // bitfield
         ProvidesImage = 1,
@@ -221,7 +221,7 @@ public:
 
     void deleteFrameSet( KWFrameSet *);
 
-    TQPtrList<KAction> listOfResultOfCheckWord( const TQString &word );
+    TQPtrList<TDEAction> listOfResultOfCheckWord( const TQString &word );
 
     int  tableSelectCell(const TQString &tableName, uint row, uint col);
     void tableInsertRow(uint row, KWTableFrameSet *table = 0);
@@ -497,11 +497,11 @@ protected slots:
 
 protected:
     void addVariableActions( int type, const TQStringList & texts,
-                             KActionMenu * parentMenu, const TQString & menuText );
+                             TDEActionMenu * parentMenu, const TQString & menuText );
 
-    void loadexpressionActions( KActionMenu * parentMenu);
+    void loadexpressionActions( TDEActionMenu * parentMenu);
 
-    void createExpressionActions( KActionMenu * parentMenu,const TQString& filename,int &i , bool insertSepar, const TQMap<TQString, KShortcut>& personalShortCut );
+    void createExpressionActions( TDEActionMenu * parentMenu,const TQString& filename,int &i , bool insertSepar, const TQMap<TQString, TDEShortcut>& personalShortCut );
 
     void showParagraphDialog( int initialPage = -1, double initialTabPos = 0.0 );
 
@@ -556,207 +556,207 @@ private:  // methods
 private: // variables
     KWDocument *m_doc;
 
-    KAction *m_actionFileStatistics;
-    KAction *m_actionEditCut;
-    KAction *m_actionEditCopy;
-    KAction *m_actionEditPaste;
-    KAction *m_actionEditSelectAll;
-    KAction *m_actionEditSelectCurrentFrame;
-    KAction *m_actionEditDelFrame;
-    KAction *m_actionCreateLinkedFrame;
-    KAction *m_actionRaiseFrame;
-    KAction *m_actionLowerFrame;
-    KAction *m_actionSendBackward;
-    KAction *m_actionBringToFront;
+    TDEAction *m_actionFileStatistics;
+    TDEAction *m_actionEditCut;
+    TDEAction *m_actionEditCopy;
+    TDEAction *m_actionEditPaste;
+    TDEAction *m_actionEditSelectAll;
+    TDEAction *m_actionEditSelectCurrentFrame;
+    TDEAction *m_actionEditDelFrame;
+    TDEAction *m_actionCreateLinkedFrame;
+    TDEAction *m_actionRaiseFrame;
+    TDEAction *m_actionLowerFrame;
+    TDEAction *m_actionSendBackward;
+    TDEAction *m_actionBringToFront;
 
-    KAction *m_actionEditCustomVars;
-    KAction *m_actionEditCustomVarsEdit;
-    KAction *m_actionEditFind;
-    KAction *m_actionEditFindNext;
-    KAction *m_actionEditFindPrevious;
-    KAction *m_actionEditReplace;
-    KAction *m_actionApplyAutoFormat;
+    TDEAction *m_actionEditCustomVars;
+    TDEAction *m_actionEditCustomVarsEdit;
+    TDEAction *m_actionEditFind;
+    TDEAction *m_actionEditFindNext;
+    TDEAction *m_actionEditFindPrevious;
+    TDEAction *m_actionEditReplace;
+    TDEAction *m_actionApplyAutoFormat;
 
-    KToggleAction *m_actionViewTextMode;
-    KToggleAction *m_actionViewPageMode;
-    KToggleAction *m_actionViewPreviewMode;
+    TDEToggleAction *m_actionViewTextMode;
+    TDEToggleAction *m_actionViewPageMode;
+    TDEToggleAction *m_actionViewPreviewMode;
 
-    KToggleAction *m_actionViewFormattingChars;
-    KToggleAction *m_actionViewFrameBorders;
-    KToggleAction *m_actionViewHeader;
-    KToggleAction *m_actionViewFooter;
-    KToggleAction *m_actionViewFootNotes;
-    KToggleAction *m_actionViewEndNotes;
-    KToggleAction *m_actionShowDocStruct;
-    KToggleAction *m_actionShowRuler;
-    KToggleAction *m_actionViewShowGrid;
-    KToggleAction *m_actionViewSnapToGrid;
-    KToggleAction *m_actionAllowAutoFormat;
+    TDEToggleAction *m_actionViewFormattingChars;
+    TDEToggleAction *m_actionViewFrameBorders;
+    TDEToggleAction *m_actionViewHeader;
+    TDEToggleAction *m_actionViewFooter;
+    TDEToggleAction *m_actionViewFootNotes;
+    TDEToggleAction *m_actionViewEndNotes;
+    TDEToggleAction *m_actionShowDocStruct;
+    TDEToggleAction *m_actionShowRuler;
+    TDEToggleAction *m_actionViewShowGrid;
+    TDEToggleAction *m_actionViewSnapToGrid;
+    TDEToggleAction *m_actionAllowAutoFormat;
 
-    KToggleAction *m_actionAllowBgSpellCheck;
+    TDEToggleAction *m_actionAllowBgSpellCheck;
 
-    KSelectAction *m_actionViewZoom;
+    TDESelectAction *m_actionViewZoom;
 
-    KAction *m_actionInsertFrameBreak;
-    KAction *m_actionInsertFootEndNote;
-    KAction *m_actionInsertContents;
-    KAction *m_actionInsertLink;
-    KAction *m_actionInsertComment;
-    KAction *m_actionEditComment;
-    KAction *m_actionRemoveComment;
-    KAction *m_actionCopyTextOfComment;
-    //KAction *actionInsertPage;
-    KAction *m_actionDeletePage;
+    TDEAction *m_actionInsertFrameBreak;
+    TDEAction *m_actionInsertFootEndNote;
+    TDEAction *m_actionInsertContents;
+    TDEAction *m_actionInsertLink;
+    TDEAction *m_actionInsertComment;
+    TDEAction *m_actionEditComment;
+    TDEAction *m_actionRemoveComment;
+    TDEAction *m_actionCopyTextOfComment;
+    //TDEAction *actionInsertPage;
+    TDEAction *m_actionDeletePage;
 
-    KActionMenu *actionInsertVariable;
+    TDEActionMenu *actionInsertVariable;
     struct VariableDef {
         int type;
         int subtype;
     };
-    typedef TQMap<KAction *, VariableDef> VariableDefMap;
-    KActionMenu *m_actionInsertExpression;
+    typedef TQMap<TDEAction *, VariableDef> VariableDefMap;
+    TDEActionMenu *m_actionInsertExpression;
 
-    KActionMenu *m_actionInsertCustom;
+    TDEActionMenu *m_actionInsertCustom;
 
     VariableDefMap m_variableDefMap;
-    KAction *m_actionInsertFormula;
-    KAction *m_actionInsertTable;
-    KAction *m_actionAutoFormat;
+    TDEAction *m_actionInsertFormula;
+    TDEAction *m_actionInsertTable;
+    TDEAction *m_actionAutoFormat;
 
-    KToggleAction *m_actionToolsCreateText;
-    KToggleAction *m_actionToolsCreatePix;
+    TDEToggleAction *m_actionToolsCreateText;
+    TDEToggleAction *m_actionToolsCreatePix;
     KoPartSelectAction *m_actionToolsCreatePart;
 
-    KAction *m_actionFormatFont;
-    KAction *m_actionFormatDefault;
-    KAction *m_actionFormatFrameStylist;
-    KAction *m_actionFormatStylist;
-    KAction *m_actionFormatPage;
+    TDEAction *m_actionFormatFont;
+    TDEAction *m_actionFormatDefault;
+    TDEAction *m_actionFormatFrameStylist;
+    TDEAction *m_actionFormatStylist;
+    TDEAction *m_actionFormatPage;
 
-    KAction *m_actionFontSizeIncrease;
-    KAction *m_actionFontSizeDecrease;
+    TDEAction *m_actionFontSizeIncrease;
+    TDEAction *m_actionFontSizeDecrease;
 
-    KFontSizeAction *m_actionFormatFontSize;
-    KFontAction *m_actionFormatFontFamily;
-    KSelectAction *m_actionFormatStyle;
-    KActionMenu *m_actionFormatStyleMenu;
-    KToggleAction *m_actionFormatBold;
-    KToggleAction *m_actionFormatItalic;
-    KToggleAction *m_actionFormatUnderline;
-    KToggleAction *m_actionFormatStrikeOut;
-    TKSelectColorAction *m_actionFormatColor;
-    KToggleAction *m_actionFormatAlignLeft;
-    KToggleAction *m_actionFormatAlignCenter;
-    KToggleAction *m_actionFormatAlignRight;
-    KToggleAction *m_actionFormatAlignBlock;
-    KToggleAction *m_actionFormatSpacingSingle;
-    KToggleAction *m_actionFormatSpacingOneAndHalf;
-    KToggleAction *m_actionFormatSpacingDouble;
-    KAction *m_actionFormatParag;
-    KAction *m_actionFormatFrameSet;
-    KAction *m_actionFormatIncreaseIndent;
-    KAction *m_actionFormatDecreaseIndent;
-    KActionMenu *m_actionFormatBullet;
-    KActionMenu *m_actionFormatNumber;
-    KToggleAction *m_actionFormatSuper;
-    KToggleAction *m_actionFormatSub;
-    KAction* m_actionInsertSpecialChar;
+    TDEFontSizeAction *m_actionFormatFontSize;
+    TDEFontAction *m_actionFormatFontFamily;
+    TDESelectAction *m_actionFormatStyle;
+    TDEActionMenu *m_actionFormatStyleMenu;
+    TDEToggleAction *m_actionFormatBold;
+    TDEToggleAction *m_actionFormatItalic;
+    TDEToggleAction *m_actionFormatUnderline;
+    TDEToggleAction *m_actionFormatStrikeOut;
+    TTDESelectColorAction *m_actionFormatColor;
+    TDEToggleAction *m_actionFormatAlignLeft;
+    TDEToggleAction *m_actionFormatAlignCenter;
+    TDEToggleAction *m_actionFormatAlignRight;
+    TDEToggleAction *m_actionFormatAlignBlock;
+    TDEToggleAction *m_actionFormatSpacingSingle;
+    TDEToggleAction *m_actionFormatSpacingOneAndHalf;
+    TDEToggleAction *m_actionFormatSpacingDouble;
+    TDEAction *m_actionFormatParag;
+    TDEAction *m_actionFormatFrameSet;
+    TDEAction *m_actionFormatIncreaseIndent;
+    TDEAction *m_actionFormatDecreaseIndent;
+    TDEActionMenu *m_actionFormatBullet;
+    TDEActionMenu *m_actionFormatNumber;
+    TDEToggleAction *m_actionFormatSuper;
+    TDEToggleAction *m_actionFormatSub;
+    TDEAction* m_actionInsertSpecialChar;
 
     // Text and Frame borders.
-    KSelectAction *m_actionFrameStyle;
-    KActionMenu *m_actionFrameStyleMenu;
-    KSelectAction *m_actionTableStyle;
-    KActionMenu *m_actionTableStyleMenu;
-    KToggleAction *m_actionBorderLeft;
-    KToggleAction *m_actionBorderRight;
-    KToggleAction *m_actionBorderTop;
-    KToggleAction *m_actionBorderBottom;
-    KToggleAction *m_actionBorderOutline;
-    TKSelectColorAction *m_actionBorderColor;
-    KSelectAction *m_actionBorderWidth;
-    KSelectAction *m_actionBorderStyle;
-    TKSelectColorAction *m_actionBackgroundColor;
+    TDESelectAction *m_actionFrameStyle;
+    TDEActionMenu *m_actionFrameStyleMenu;
+    TDESelectAction *m_actionTableStyle;
+    TDEActionMenu *m_actionTableStyleMenu;
+    TDEToggleAction *m_actionBorderLeft;
+    TDEToggleAction *m_actionBorderRight;
+    TDEToggleAction *m_actionBorderTop;
+    TDEToggleAction *m_actionBorderBottom;
+    TDEToggleAction *m_actionBorderOutline;
+    TTDESelectColorAction *m_actionBorderColor;
+    TDESelectAction *m_actionBorderWidth;
+    TDESelectAction *m_actionBorderStyle;
+    TTDESelectColorAction *m_actionBackgroundColor;
 
-    KAction *m_actionTableDelRow;
-    KAction *m_actionTableDelCol;
-    KAction *m_actionTableInsertRow;
-    KAction *m_actionTableInsertCol;
-    KAction *m_actionTableResizeCol;
-    KAction *m_actionTableJoinCells;
-    KAction *m_actionTableSplitCells;
-    KAction *m_actionConvertTableToText;
-    KAction *m_actionSortText;
-    KAction *m_actionAddPersonalExpression;
-    KToggleAction *m_actionTableProtectCells;
+    TDEAction *m_actionTableDelRow;
+    TDEAction *m_actionTableDelCol;
+    TDEAction *m_actionTableInsertRow;
+    TDEAction *m_actionTableInsertCol;
+    TDEAction *m_actionTableResizeCol;
+    TDEAction *m_actionTableJoinCells;
+    TDEAction *m_actionTableSplitCells;
+    TDEAction *m_actionConvertTableToText;
+    TDEAction *m_actionSortText;
+    TDEAction *m_actionAddPersonalExpression;
+    TDEToggleAction *m_actionTableProtectCells;
 
-    KAction *m_actionTableUngroup;
-    KAction *m_actionTableDelete;
+    TDEAction *m_actionTableUngroup;
+    TDEAction *m_actionTableDelete;
 
-    KAction *m_actionTableStylist;
-    KAction *m_actionTablePropertiesMenu;
-    KAction *m_actionTableProperties;
+    TDEAction *m_actionTableStylist;
+    TDEAction *m_actionTablePropertiesMenu;
+    TDEAction *m_actionTableProperties;
 
-    KAction *m_actionExtraCreateTemplate;
+    TDEAction *m_actionExtraCreateTemplate;
 
-    KAction *m_actionChangeCase;
+    TDEAction *m_actionChangeCase;
 
-    KAction *m_actionEditPersonnalExpr;
+    TDEAction *m_actionEditPersonnalExpr;
 
-    KAction *m_actionConfigure;
+    TDEAction *m_actionConfigure;
 
-    KAction *m_actionConfigureCompletion;
+    TDEAction *m_actionConfigureCompletion;
 
-    KAction *m_actionSavePicture;
+    TDEAction *m_actionSavePicture;
 
-    KAction *m_actionConfigureHeaderFooter;
-    KToggleAction *m_actionInlineFrame;
+    TDEAction *m_actionConfigureHeaderFooter;
+    TDEToggleAction *m_actionInlineFrame;
 
-    KAction *m_actionOpenLink;
-    KAction *m_actionChangeLink;
-    KAction *m_actionCopyLink;
-    KAction *m_actionAddLinkToBookmak;
-    KAction *m_actionRemoveLink;
+    TDEAction *m_actionOpenLink;
+    TDEAction *m_actionChangeLink;
+    TDEAction *m_actionCopyLink;
+    TDEAction *m_actionAddLinkToBookmak;
+    TDEAction *m_actionRemoveLink;
 
-    KAction *m_actionRefreshAllVariable;
-    KAction *m_actionCreateStyleFromSelection;
+    TDEAction *m_actionRefreshAllVariable;
+    TDEAction *m_actionCreateStyleFromSelection;
 
-    KAction *m_actionConfigureFootEndNote;
+    TDEAction *m_actionConfigureFootEndNote;
 
-    KAction *m_actionEditFootEndNote;
+    TDEAction *m_actionEditFootEndNote;
 
-    KAction *m_actionChangeFootNoteType;
+    TDEAction *m_actionChangeFootNoteType;
 
-    KAction *m_actionGoToFootEndNote;
+    TDEAction *m_actionGoToFootEndNote;
 
     // Document Structure Area popup menu.
-    KAction *m_actionDocStructEdit;
-    KAction *m_actionDocStructSpeak;
-    KAction *m_actionDocStructSelect;
-    KAction *m_actionDocStructDelete;
-    KAction *m_actionDocStructProperties;
+    TDEAction *m_actionDocStructEdit;
+    TDEAction *m_actionDocStructSpeak;
+    TDEAction *m_actionDocStructSelect;
+    TDEAction *m_actionDocStructDelete;
+    TDEAction *m_actionDocStructProperties;
 
-    KAction *m_actionInsertFile;
+    TDEAction *m_actionInsertFile;
 
-    KAction *m_actionAddBookmark;
-    KAction *m_actionSelectBookmark;
+    TDEAction *m_actionAddBookmark;
+    TDEAction *m_actionSelectBookmark;
 
-    KAction *m_actionImportStyle;
+    TDEAction *m_actionImportStyle;
 
-    KAction *m_actionCreateFrameStyle;
+    TDEAction *m_actionCreateFrameStyle;
 
-    KAction *m_actionConvertToTextBox;
+    TDEAction *m_actionConvertToTextBox;
 
-    KAction *m_actionSpellIgnoreAll;
-    KAction *m_actionSpellCheck;
+    TDEAction *m_actionSpellIgnoreAll;
+    TDEAction *m_actionSpellCheck;
 
-    KToggleAction *m_actionEmbeddedStoreInternal;
+    TDEToggleAction *m_actionEmbeddedStoreInternal;
 
-    KAction *m_actionAddWordToPersonalDictionary;
+    TDEAction *m_actionAddWordToPersonalDictionary;
 
-    KToggleAction *m_actionInsertDirectCursor;
+    TDEToggleAction *m_actionInsertDirectCursor;
 
-    KAction *m_actionGoToDocumentStructure;
-    KAction *m_actionGoToDocument;
+    TDEAction *m_actionGoToDocumentStructure;
+    TDEAction *m_actionGoToDocument;
 
 
     KoCharSelectDia *m_specialCharDlg;
@@ -770,9 +770,9 @@ private: // variables
     KoSearchContext *m_searchEntry, *m_replaceEntry;
     KWFindReplace *m_findReplace;
 
-    TQPtrList<KAction> m_actionList; // for the kodatatools
-    TQPtrList<KAction> m_variableActionList;
-    TQPtrList<KAction> m_tableActionList;
+    TQPtrList<TDEAction> m_actionList; // for the kodatatools
+    TQPtrList<TDEAction> m_variableActionList;
+    TQPtrList<TDEAction> m_tableActionList;
 
     KWPage *m_currentPage; ///< current page number
 
@@ -819,7 +819,7 @@ private: // variables
 class KWViewWidget : public TQWidget
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     KWViewWidget( TQWidget *parent, KWView *view );
@@ -838,7 +838,7 @@ protected:
 class KWGUI : public TQHBox
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     KWGUI( const TQString& viewMode, TQWidget *parent, KWView *view );
