@@ -24,8 +24,8 @@
 #include "KoXmlNS.h"
 #include "KoGenStyles.h"
 #include <tqbuffer.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <tqbrush.h>
 #include <KoStyleStack.h>
 
