@@ -26,25 +26,25 @@
 
 #include "KoTemplateChooseDia.h"
 
-#include <klocale.h>
-#include <kdeversion.h>
-#include <kfiledialog.h>
+#include <tdelocale.h>
+#include <tdeversion.h>
+#include <tdefiledialog.h>
 #include <kinstance.h>
 #include <KoFilterManager.h>
 #include <KoTemplates.h>
 #include <KoDocument.h>
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
 
 #include <kdebug.h>
 #include <kpushbutton.h>
 #include <kjanuswidget.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <ktextedit.h>
-#include <kfileiconview.h>
-#include <kfileitem.h>
-#include <kmessagebox.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdefileiconview.h>
+#include <tdefileitem.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
 
 #include <tqapplication.h>
 #include <tqlayout.h>
@@ -119,7 +119,7 @@ private:
 
 class KoTemplateChooseDiaPrivate {
     public:
-	KoTemplateChooseDiaPrivate(const TQCString& templateType, KInstance* instance,
+	KoTemplateChooseDiaPrivate(const TQCString& templateType, TDEInstance* instance,
                                    const TQCString &format,
                                    const TQString &nativeName,
                                    const TQStringList& extraNativeMimeTypes,
@@ -136,7 +136,7 @@ class KoTemplateChooseDiaPrivate {
 	~KoTemplateChooseDiaPrivate() {}
 
 	TQCString m_templateType;
-	KInstance* m_instance;
+	TDEInstance* m_instance;
 	TQCString m_format;
 	TQString m_nativeName;
         TQStringList m_extraNativeMimeTypes;
@@ -178,7 +178,7 @@ class KoTemplateChooseDiaPrivate {
 /******************************************************************/
 
 /*================================================================*/
-KoTemplateChooseDia::KoTemplateChooseDia(TQWidget *parent, const char *name, KInstance* instance,
+KoTemplateChooseDia::KoTemplateChooseDia(TQWidget *parent, const char *name, TDEInstance* instance,
                                          const TQCString &format,
                                          const TQString &nativeName,
                                          const TQStringList &extraNativeMimeTypes,
@@ -223,11 +223,11 @@ KoTemplateChooseDia::~KoTemplateChooseDia()
 // Keep in sync with KoMainWindow::chooseNewDocument
 static bool cancelQuits() {
     bool onlyDoc = !KoDocument::documentList() || KoDocument::documentList()->count() <= 1;
-    bool onlyMainWindow = !KMainWindow::memberList || KMainWindow::memberList->count() <= 1;
+    bool onlyMainWindow = !TDEMainWindow::memberList || TDEMainWindow::memberList->count() <= 1;
     return onlyDoc && onlyMainWindow && kapp->instanceName() != "koshell"; // hack for koshell
 }
 
-KoTemplateChooseDia::ReturnType KoTemplateChooseDia::choose(KInstance* instance, TQString &file,
+KoTemplateChooseDia::ReturnType KoTemplateChooseDia::choose(TDEInstance* instance, TQString &file,
                                                             const KoTemplateChooseDia::DialogType &dialogType,
                                                             const TQCString& templateType,
                                                             TQWidget* parent)
@@ -241,7 +241,7 @@ KoTemplateChooseDia::ReturnType KoTemplateChooseDia::choose(KInstance* instance,
                    dialogType, templateType, parent );
 }
 
-KoTemplateChooseDia::ReturnType KoTemplateChooseDia::choose(KInstance* instance, TQString &file,
+KoTemplateChooseDia::ReturnType KoTemplateChooseDia::choose(TDEInstance* instance, TQString &file,
                                        const TQCString &format,
                                        const TQString &nativeName,
                                        const TQStringList& extraNativeMimeTypes,
@@ -315,7 +315,7 @@ void KoTemplateChooseDia::setupRecentDialog(TQWidget * widgetbase, TQGridLayout
                 TQString key=TQString( "File%1" ).arg( i );
                 value=d->m_instance->config()->readPathEntry( key );
                 if ( !value.isEmpty() ) {
-                    // Support for kdelibs-3.5's new RecentFiles format: name[url]
+                    // Support for tdelibs-3.5's new RecentFiles format: name[url]
                     TQString s = value;
                     if ( s.endsWith("]") )
                     {
@@ -403,7 +403,7 @@ void KoTemplateChooseDia::setupTemplateDialog(TQWidget * widgetbase, TQGridLayou
     layout->addWidget(d->boxdescription, 1, 0 );
 
     // config
-    KConfigGroup grp( d->m_instance->config(), "TemplateChooserDialog" );
+    TDEConfigGroup grp( d->m_instance->config(), "TemplateChooserDialog" );
     int templateNum = grp.readNumEntry( "TemplateTab", -1 );
     TQString templateName = grp.readPathEntry( "TemplateName" );
 	if ( templateName.isEmpty() && d->tree->defaultTemplate() )
@@ -504,7 +504,7 @@ void KoTemplateChooseDia::setupDialog()
 {
 
     TQGridLayout *maingrid=new TQGridLayout( d->m_mainwidget, 1, 1, 2, 6);
-    KConfigGroup grp( d->m_instance->config(), "TemplateChooserDialog" );
+    TDEConfigGroup grp( d->m_instance->config(), "TemplateChooserDialog" );
 
     if (d->m_dialogType == Everything)
     {
@@ -638,7 +638,7 @@ void KoTemplateChooseDia::slotOk()
     if (collectInfo())
     {
 	// Save it for the next time
-	KConfigGroup grp( d->m_instance->config(), "TemplateChooserDialog" );
+	TDEConfigGroup grp( d->m_instance->config(), "TemplateChooserDialog" );
 	static const char* const s_returnTypes[] = { 0 /*Cancel ;)*/, "Template", "File", "Empty" };
 	if ( d->m_returnType <= Empty )
 	{
@@ -746,7 +746,7 @@ TQString KoTemplateChooseDia::descriptionText(const TQString &name, const TQStri
 
 /*================================================================*/
 
-TQIconViewItem * KoTCDIconCanvas::load( KoTemplateGroup *group, const TQString& name, KInstance* instance )
+TQIconViewItem * KoTCDIconCanvas::load( KoTemplateGroup *group, const TQString& name, TDEInstance* instance )
 {
     TQIconViewItem * itemtoreturn = 0;
 
