@@ -22,12 +22,12 @@
 
 #include <kolanguagetabbase.h>
 
-#include <kspell2/broker.h>
+#include <tdespell2/broker.h>
 
 class KoLanguageTab : public KoLanguageTabBase
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     KoLanguageTab( KSpell2::Broker::Ptr broker = 0, TQWidget* parent=0, const char* name=0, WFlags fl=0 );
