@@ -24,7 +24,7 @@
 #include <KoFontDia.h>
 #include <KoGlobal.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kdebug.h>
 
@@ -148,12 +148,12 @@ void KoStyleManager::setupWidget(const KoStyleCollection& styleCollection)
 
 
     m_moveUpButton = new TQPushButton( frame1, "moveUpButton" );
-    m_moveUpButton->setIconSet( SmallIconSet( "up" ) );
+    m_moveUpButton->setIconSet( SmallIconSet( "go-up" ) );
     connect( m_moveUpButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( moveUpStyle() ) );
     frame1Layout->addWidget( m_moveUpButton, 1, 1 );
 
     m_moveDownButton = new TQPushButton( frame1, "moveDownButton" );
-    m_moveDownButton->setIconSet( SmallIconSet( "down" ) );
+    m_moveDownButton->setIconSet( SmallIconSet( "go-down" ) );
     connect( m_moveDownButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( moveDownStyle() ) );
     frame1Layout->addWidget( m_moveDownButton, 1, 0 );
 
@@ -683,7 +683,7 @@ KoStyleFontTab::KoStyleFontTab( TQWidget * parent )
 	( new TQVBoxLayout( this ) )->setAutoAdd( true );
 	TQTabWidget *fontTabContainer = new TQTabWidget( this );
 
-	m_fontTab = new KoFontTab( KFontChooser::SmoothScalableFonts, this );
+	m_fontTab = new KoFontTab( TDEFontChooser::SmoothScalableFonts, this );
 	m_decorationTab = new KoDecorationTab( this );
 	m_highlightingTab = new KoHighlightingTab( this );
 	m_layoutTab = new KoLayoutTab( true, this );
