@@ -26,14 +26,14 @@
 #include "KoBgSpellCheck.h"
 #include "KoVariable.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <kstdaccel.h>
+#include <tdestdaccel.h>
 #include <kdebug.h>
 #include <kinstance.h>
 #include <kdatatool.h>
 #include <krun.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kcommand.h>
 #include <kbookmarkmanager.h>
 #include <kbookmark.h>
@@ -175,14 +175,14 @@ void KoTextView::handleKeyPressEvent( TQKeyEvent * e, TQWidget *widget, const TQ
     }*/
 
     bool clearUndoRedoInfo = TRUE;
-    if ( KShortcut( KKey( e ) ) == KStdAccel::deleteWordBack() )
+    if ( TDEShortcut( KKey( e ) ) == TDEStdAccel::deleteWordBack() )
     {
         if ( m_cursor->parag()->string()->isRightToLeft() )
             deleteWordRight();
         else
             deleteWordLeft();
         clearUndoRedoInfo = TRUE;
-    } else if ( KShortcut( KKey( e ) ) == KStdAccel::deleteWordForward() )
+    } else if ( TDEShortcut( KKey( e ) ) == TDEStdAccel::deleteWordForward() )
     {
         if ( m_cursor->parag()->string()->isRightToLeft() )
             deleteWordLeft();
@@ -355,9 +355,9 @@ void KoTextView::handleKeyPressEvent( TQKeyEvent * e, TQWidget *widget, const TQ
                      removeToolTipCompletion();
 
             }
-            // We should use KAccel instead, to make this configurable !
+            // We should use TDEAccel instead, to make this configurable !
             // Well, those are all alternate keys, for keys already configurable (KDE-wide)
-            // and a kaccel makes it hard to
+            // and a tdeaccel makes it hard to
             else
 	    {
                 if ( e->state() & ControlButton ) {
@@ -1087,7 +1087,7 @@ KoLinkVariable * KoTextView::linkVariable()
     return dynamic_cast<KoLinkVariable *>(variable());
 }
 
-TQPtrList<KAction> KoTextView::dataToolActionList(KInstance * instance, const TQString& word, bool & _singleWord )
+TQPtrList<TDEAction> KoTextView::dataToolActionList(TDEInstance * instance, const TQString& word, bool & _singleWord )
 {
     m_singleWord = false;
     m_wordUnderCursor = TQString();
@@ -1118,7 +1118,7 @@ TQPtrList<KAction> KoTextView::dataToolActionList(KInstance * instance, const TQ
     }
 
     if ( text.isEmpty() || textObject()->protectContent()) // Nothing to apply a tool to
-        return TQPtrList<KAction>();
+        return TQPtrList<TDEAction>();
 
     // Any tool that works on plain text is relevant
     TQValueList<KDataToolInfo> tools;
