@@ -31,7 +31,9 @@
 #include <rubysig.h>
 #include <node.h>
 #else // HAVE_RUBY_1_9
+#ifndef HAVE_RUBY_3
 #include <ruby/backward/rubysig.h>
+#endif // HAVE_RUBY_3
 #endif // HAVE_RUBY_1_9
 
 #include <main/scriptcontainer.h>
