@@ -20,7 +20,7 @@
 #ifndef SCAN_H
 #define SCAN_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 #include <tqimage.h>
 
 class KScanDialog;
@@ -28,7 +28,7 @@ class KScanDialog;
 class Scan : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     public:
 	Scan(TQObject *parent, const char *name, const TQStringList &);
 	virtual ~Scan();
